;;;  -*- mode: LISP; Package: CL-USER; Syntax: COMMON-LISP;  Base: 10 -*-
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; 
;;; Author      : Frank Tamborello & Mike Byrne
;;; Copyright   : (c)2008 Rice University/Frank Tamborello, All Rights Reserved
;;; Availability: public domain
;;; Address     : Rice University
;;;             : Psychology Department
;;;             : Houston,TX 77251-1892
;;;             : frank.tambo@gmail.com
;;; 
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; 
;;; Filename    : tamborello-dissertation-model.lisp
;;; Version     : r37
;;; 
;;; Description : ACT-R model of CHIL X84 for Frank's dissertation
;;;
;;; Usage       : Use to help earn a PhD for Frank! (:
;;; 
;;; Bugs        : ...in progress
;;; 
;;; Todo        : 
;;; 
;;; ----- History -----
;;; 2008-12-9 fpt [r37]
;;;	: Separate chunk for synchronous-mode2.
;;; 2008-12-7 fpt [r36]
;;;	: Replaced the find-location failure production that simply loops back to the retrieve step with a smarter algorithm that acts like it's heard the buzzer: it either tries to retrieve the same thing again or tries to retrieve something different.
;;; 2008-12-4 fpt [r35]
;;;	: Eliminated the middle slot specification for the two phaser tracking productions in all models.
;;; 2008-12-3 fpt [r34]
;;;	: added a separate tracking2 chunk & accompanying chunk parameters
;;; 2008-11-27 fpt [r33]
;;;	: added sjis for jammer's scanner flagged steps & change instructions
;;; 2008-11-21 fpt [r32]
;;;	: return to r29's parameters
;;; 2008-11-15 fpt [r17 - 29]
;;;	: parameter adjustments
;;; 2008-11-14 fpt [r16]
;;;	: Deleted no-longer used main-control DM & productions.
;;; 2008-11-08 fpt [r15b5]
;;;	: Got rid of jammer2's own beam-failed production
;;;	: Eliminated task slot of change-instruction chunk-type
;;;	: Eliminated flagged-step productions for transporter2
;;; 2008-11-08 fpt [r15b4]
;;;	: Added a task slot to the change-instruction chunk-type
;;; 2008-11-06 fpt [r15b3]
;;;	: Added a check of the color slot in the generic find and two power-connected-verify productions to fix a phaser bug.
;;; 2008-11-03 fpt [r15b2]
;;;	: Moved code that set the goal & imaginal chunks to that of the next task from the main-control verify productions into X84-actr.lisp's task-window method.
;;; 2008-11-01 fpt [r15b]
;;;	: X84 had no effect of semantic labels, so do away with all the LSA-Sji & label stuff.
;;;	: Add an interface chunk slot so that old node-names can be inhibited
;;;	: Added productions to the cond 1 & 2 models to monitor for flagged steps and then harness the new changed-instruction chunks added by instruct-actr in the experiment file
;;;	: Added global variables to control certain parameters for all models together.
;;; 2008-10-30 fpt [r14.3]
;;;	: Added a "verify" stroke to the now retrieve-find-move-act-verify loop. That way the model will have a chance to hear/not hear the buzzer before it updates its imaginal chunk.
;;; 2008-10-30 fpt [r14.2]
;;;	: The model matches its click production to the contents of the goal chunk's state-global and the imaginal chunk's bottom slots, but does whatever the retrieved chunk specifies. Instead, match the click production to the retrieved chunk.
;;; 2008-10-30 fpt [r14.1]
;;;	: incorporates r15's work on declarative subsymbolic computation, namely the low declarative parameter values and the never requesting the retrieval of a negated node-name
;;; 2008-10-27 fpt [r14]
;;;	: Implement a new behavioral loop: find visual-location, move cursor, click, retrieve next visual-location
;;; 2008-10-22 fpt [r13]
;;;	: Use a different chunk in the imaginal module, one that contains direct references to the current CSM chunk at each level of the goal hierarchy
;;;	: Keep a direct reference to the current CSM action in the state-global slot of the goal chunk throughout all productions involved in each action
;;;	: Have something in all goal slots at all times?
;;; 2008-10-19 fpt [r12]
;;;	: Added "error recovery" value to state-micro slot of goal chunk to keep the model from interrupting itself between retrieving an action to perform and actually performing that action
;;;	while it's engaged in error recovery.
;;;	: Switched on imaginal-activation to the buffer-params module so that activation would actually _spread_ from the chunk in the imaginal module during a retrieval request.
;;;	: I was having a bug caused by the default 200 ms lag in chunk creation time for the imaginal module - the last production of the main-control task called for the creation
;;;	of the "do-phaser" chunk, for example, but it wouldn't be created in time to start the phaser task. So I moved that imaginal chunk creation up to the time when the model reads whatever
;;;	task it's to do next.
;;; 2008-10-19 fpt [r11]
;;;	: Add LHS tests of imaginal buffer to prevent productions for the wrong interface firing - ie power-connected in transporter task.
;;; 2008-10-10 fpt [r10]
;;;	: Set similarities of chunks w/in same subtask to very high, similarities of chunks w/in task to high, left similarities of chunks in different tasks at default.
;;;
;;; 2008-10-08 fpt [r9b]
;;;	: Ditched any sort of attempt at moving the phaser targeting blip.
;;; 2008-10-08 fpt [r9a]
;;;	: This model seems to - at least for the phaser - show a nice ability to do the task, sometimes erring, many times recovering from error, but always
;;;	seemingly to keep trying things until it gets it right or the time limit expires.
;;; 2008-10-04 fpt [r9]
;;;	: The goal chunk has 13 slots! No wonder productions are failing to match and wrong chunks are being retrieved so frequently! Disentangle the goal & schema DM chunks.
;;; 2008-10-03 fpt [r8]
;;;	: Productions now do not request new visual-locations until the motor module is totally free - that way if a wrong item is clicked, the wrong item is still in the visual-location buffer and aids with error recovery.
;;; 2008-10-03 fpt [r7]
;;;	: Error recovery productions are engaging without the warning tone having played and thus are actually interfering with the productions that actually perform the correct actions.
;;;	So they now only match after the warning tone has been heard
;;;
;;; 2008-10-02 fpt [r6]
;;;	: Added node-name slot to label chunk-types
;;; 2008-10-01 fpt [r6]
;;;	: removed the parent slot from the schema & find-button chunk types so that the transporter & jammer dm networks could overlap,
;;;	consequently upward network traversal (i.e., error recovery looking for parent chunk) occurs by activating the current chunk's node-name and requesting
;;;	a schema chunk with a node-name not equal to the current node-name
;;; 2008-09-28 fpt [r5]
;;;	: Added chunk-type label, find-button chunk-types now refer to the label chunks instead of holding the label values directly.
;;;	: Added label chunks & added their sjis.
;;;	: Added error-recovery productions that work by looking for labels and then retrieving associated find-button chunks.  
;;; 2008-09-24 fpt [r4.4]
;;;	: Replaced chunk-type "action" with action descriptors that are more specific, like "move-cursor" and "type."
;;; 2008-09-24 fpt [r4.3]
;;;	: Most (all?) productions request and check for more specific visual-location chunks than just the X & Y coordinates and it makes sense that people make work with that other information, too, so add it to the action chunks.
;;; 2008-09-24 fpt [r4.2]
;;;	: Removing the childx-done slots from the schema chunks since I never seem to use them.
;;;	: Repeated steps get one chunk, not two
;;; 2008-09-23 fpt [r4.1]
;;;	: ...continuing with error recovery - adding a =visual-location> to the LHS
;;;	of every production that clicks the mouse and a +retrieval> to the RHS
;;; 2008-09-22 fpt [r4]
;;;	: Began building an error-recovery mechanism 
;;; 2008-09-18 fpt [r3]
;;;	: Separate models for each condition
;;; 2008-09-14 fpt [r2]
;;;	: Added declarative memory
;;; 2008-05-15 fpt [r1]
;;;	: Inception, using ACT-R 6 r603.
;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


#|
(defun *+load-the-other-files ())
|#
;; (load "dissertation-model:actr;load-act-r-6.lisp")
;; (load "dissertation-model:x84-actr.lisp")
;; (load "dissertation-model:devices.lisp")


(defparameter *time-elapse-reward* -5)
(defparameter *time-elapse-reward-interval* 1)
(defparameter *correct-reward* 25)
(defparameter *error-reward* -50)
(defparameter *reward-time* 0)

(defparameter *v* nil)
(defparameter *egs* 2)
(defparameter *mp* 1.8)
(defparameter *ans* 0.23)
(defparameter *mas* 2)
(defparameter *rt* -2)



;;;; ---------------------------------------------------------------------- ;;;;
;;;; The model
;;;; ---------------------------------------------------------------------- ;;;;

(clear-all)


(define-model fdm0
  
  (sgp-fct (list
   ;; model debugging & running
   :v t :trace-detail 'low :show-focus nil
   ;; central parameters
   :er t :esc t :ol 4
   ;; procedural
   :crt nil :cst nil
   ;; utility
   :ul t :egs *egs* ;; :iu 20 ;:ut -150 
   ;; visual
   :do-not-harvest 'visual-location 
   :do-not-harvest 'visual 
   :do-not-harvest 'retrieval 
   :do-not-harvest 'imaginal 
   ;; :auto-attend t 
   ;; declarative module
   :mp *mp* :md -10 :ans *ans* :mas *mas* :rt *rt* ;; :blc 2 
   ;; :declarative-num-finsts 20 :declarative-finst-span 30.0 
   :act t 
   ;; buffer-params
   ;; :imaginal-activation 1.0
   ))
  
  (chunk-type star-trek-goal state-micro state-local state-global wm-dummy1 wm-dummy2 wm-dummy3) ;; wmd4)
  (chunk-type schema interface node-name child1 child2 child3 child4)
  (chunk-type find-button interface node-name xcor1 xcor2 ycor1 ycor2 kind value color)
  (chunk-type (type (:include find-button)) key)
  (chunk-type (check-status (:include find-button)))
  (chunk-type wm-dummy value)
  (chunk-type problem-state interface top middle bottom)
  (chunk-type change-instruction current-flag do-step do-subtask next-flag)
  
  (add-dm
   
   (finished-experiment isa star-trek-goal state-global finished-experiment state-local finished-experiment state-micro finished-experiment)
   
   
   (phaser-goal isa star-trek-goal state-global power-connected state-local retrieve state-micro nothing wm-dummy1 wm-dummy-chunk1 wm-dummy2 wm-dummy-chunk2 wm-dummy3 wm-dummy-chunk3) ;; wmd4 wmd-chunk4)
   (phaser-imaginal isa problem-state interface phaser top do-phaser middle charge-phaser bottom power-connected)
   (do-phaser isa schema interface phaser node-name do-phaser child1 charge-phaser child2 set-focus child3 firing child4 main-control-phaser)
   	(charge-phaser isa schema interface phaser node-name charge-phaser child1 power-connected child2 charge child3 stop-charging child4 power-connected2)
   		(power-connected isa find-button interface phaser node-name power-connected  xcor1 690 xcor2 730 ycor1 190 ycor2 220 kind visual-object value box color light-gray)
   		(charge isa find-button interface phaser node-name charge  xcor1 720 xcor2 760 ycor1 130 ycor2 160 kind oval value oval color light-gray)
   		(stop-charging isa find-button interface phaser node-name stop-charging  xcor1 720 xcor2 760 ycor1 260 ycor2 300 kind oval value oval color light-gray)
   		(power-connected2 isa find-button interface phaser node-name power-connected2  xcor1 690 xcor2 730 ycor1 190 ycor2 220 kind visual-object value box color blue)
   	(set-focus isa schema interface phaser node-name set-focus child1 focus child2 slider child3 focus-set child4 NOTHING)
   		(settings isa find-button interface phaser node-name settings  xcor1 470 xcor2 490 ycor1 590 ycor2 610 kind oval value oval color light-gray)
   		(slider isa find-button interface phaser node-name slider  xcor1 570 xcor2 620 ycor1 620 ycor2 680 kind visual-object value box color black)
   		(focus-set isa find-button interface phaser node-name focus-set  xcor1 580 xcor2 640 ycor1 570 ycor2 630 kind visual-object value box color light-gray)
   	(fire-phaser isa schema interface phaser node-name fire-phaser child1 firing child2 tracking child3 phaser-shoot child4 phasercheck-status)
  		(firing isa find-button interface phaser node-name firing  xcor1 120 xcor2 180 ycor1 380 ycor2 440 kind oval value oval color light-gray)
   		(tracking isa find-button interface phaser node-name tracking  xcor1 300 xcor2 360 ycor1 380 ycor2 440 kind oval value oval color light-gray)
                (phaser-shoot isa type interface phaser node-name phaser-shoot  xcor1 230 xcor2 290 ycor1 200 ycor2 260 kind visual-object value blip color black key space)
   		(phaser-check-status isa check-status interface phaser node-name phaser-check-status  xcor1 135 xcor2 175 ycor1 630 ycor2 670 kind text value text color black)
   	(main-control-phaser isa schema interface phaser node-name main-control-phaser child1 tracking2 child2 click-main-control-phaser child3 NOTHING child4 NOTHING)
   		(tracking2 isa find-button interface phaser node-name tracking2  xcor1 300 xcor2 360 ycor1 380 ycor2 440 kind oval value oval color light-gray)
   		(click-main-control-phaser isa find-button interface phaser node-name click-main-control-phaser  xcor1 780 xcor2 910 ycor1 570 ycor2 640 kind oval value oval color light-gray)

   
   (transporter-goal isa star-trek-goal state-global scanner-on state-local retrieve state-micro nothing wm-dummy1 wm-dummy-chunk1 wm-dummy2 wm-dummy-chunk2 wm-dummy3 wm-dummy-chunk3)
   (transporter-imaginal isa problem-state interface transporter top do-transporter middle scan bottom scanner-on)
   (do-transporter isa schema interface transporter node-name do-transporter child1 scan child2 frequency child3 power child4 main-control-transporter)
   	(scan isa schema interface transporter node-name scan child1 scanner-on child2 active-scan child3 lock-signal child4 scanner-off)
   		(scanner-on isa find-button interface transporter node-name scanner-on  xcor1 690 xcor2 730 ycor1 260 ycor2 280 kind oval value oval color light-gray)
   		(active-scan isa find-button interface transporter node-name active-scan  xcor1 690 xcor2 730 ycor1 300 ycor2 320 kind oval value oval color light-gray)
		(lock-signal isa find-button interface transporter node-name lock-signal  xcor1 690 xcor2 730 ycor1 320 ycor2 340 kind oval value oval color light-gray)
   		(scanner-off isa find-button interface transporter node-name scanner-off  xcor1 690 xcor2 730 ycor1 280 ycor2 300 kind oval value oval color light-gray)
   	(frequency isa schema interface transporter node-name frequency child1 enter-frequency child2 type child3 accept-frequency child4 nothing)
   		(enter-frequency isa find-button interface transporter node-name enter-frequency  xcor1 500 xcor2 530 ycor1 145 ycor2 175 kind oval value oval color light-gray)
   		(type-frequency isa type interface transporter node-name type-frequency  xcor1 460 xcor2 490 ycor1 185 ycor2 215 kind text value nothing color black key 5)
                (accept-frequency isa find-button interface transporter node-name accept-frequency  xcor1 435 xcor2 465 ycor1 215 ycor2 245 kind visual-object value box color light-gray)
        (power isa schema interface transporter node-name power child1 transporter-power child2 synchronous-mode child3 transporter-shoot child4 nothing)
        	(transporter-power isa find-button interface transporter node-name transporter-power  xcor1 185 xcor2 215 ycor1 215 ycor2 245 kind visual-object value box color light-gray)
                (synchronous-mode isa find-button interface transporter node-name synchronous-mode  xcor1 245 xcor2 275 ycor1 145 ycor2 175 kind oval value oval color light-gray)
                (transporter-shoot isa find-button interface transporter node-name transporter-shoot  xcor1 120 xcor2 450 ycor1 350 ycor2 700 kind visual-object value unknown color black)
        (main-control-transporter isa schema interface transporter node-name main-control-transporter child1 synchronous-mode2 child2 transporter-check-status child3 click-main-control-transporter child4 nothing)
                (synchronous-mode2 isa find-button interface transporter node-name synchronous-mode2  xcor1 245 xcor2 275 ycor1 145 ycor2 175 kind oval value oval color light-gray)
   		(transporter-check-status isa find-button interface transporter node-name transporter-check-status  xcor1 530 xcor2 800 ycor1 460 ycor2 500 kind text value nothing color black)
        	(click-main-control-transporter isa find-button interface transporter node-name click-main-control-transporter  xcor1 545 xcor2 575 ycor1 580 ycor2 610 kind oval value oval color light-gray)
    


  ;;; (frequency, scanner, power, shoot)
   (jammer-goal isa star-trek-goal state-global scanner-on state-local retrieve state-micro scanner-on wm-dummy1 wm-dummy-chunk1 wm-dummy2 wm-dummy-chunk2 wm-dummy3 wm-dummy-chunk3)
   (jammer-imaginal isa problem-state interface transporter top do-changed-jammer middle scan bottom scanner-on)
   (do-jammer isa schema interface transporter node-name do-jammer child1 scan child2 frequency child3 power child4 main-control-transporter)


       (intervene-jammer-scanner-on isa change-instruction current-flag scanner-on do-step active-scan do-subtask scan next-flag lock-signal)
       (intervene-jammer-lock-signal isa change-instruction current-flag lock-signal do-step scanner-off do-subtask scan next-flag enter-frequency)
       (intervene-jammer-enter-frequency isa change-instruction current-flag enter-frequency do-step lock-signal do-subtask scan next-flag scanner-off)
       (intervene-jammer-scanner-off isa change-instruction current-flag scanner-off do-step scanner-on do-subtask scan next-flag active-scan)
       (intervene-jammer-active-scan isa change-instruction current-flag active-scan do-step enter-frequency do-subtask frequency next-flag scanner-on)



   (wm-dummy-chunk1 isa wm-dummy value "a")
   (wm-dummy-chunk2 isa wm-dummy value "b")
   (wm-dummy-chunk3 isa wm-dummy value "c")
   (nothing isa wm-dummy value "nothing")
   
   ) ;; add-dm closing parenthesis

  (sdp-fct '((power-connected2 :base-level -1.2) (tracking2 :base-level -1.1) (scanner-on :base-level -0.4) (scanner-off :base-level -0.4) (synchronous-mode2 :base-level -0.4)))

   (set-similarities
    (phaser-goal do-phaser -0.95) (phaser-goal charge-phaser -0.95) (phaser-goal set-focus -0.95) (phaser-goal fire-phaser -0.95) (phaser-goal main-control-phaser -0.95)
    (do-phaser charge-phaser -0.95) (do-phaser set-focus -0.95) (do-phaser fire-phaser -0.95) (do-phaser main-control-phaser -0.95)
   	(charge-phaser power-connected -0.95) (charge-phaser charge -0.95) (charge-phaser stop-charging -0.95) (charge-phaser power-connected2 -0.95)
      (set-focus settings -0.95) (set-focus slider -0.95) (set-focus focus-set -0.95)
      (fire-phaser firing -0.95) (fire-phaser tracking -0.95) (fire-phaser phaser-shoot -0.95) (fire-phaser phaser-check-status -0.95)
      (main-control-phaser click-main-control-phaser -0.95)
      (power-connected charge -0.95) (power-connected stop-charging -0.95) (power-connected power-connected2 -0.95)
      (charge stop-charging -0.95) (charge power-connected2 -0.95)
      (stop-charging power-connected2 -0.95)
      (settings slider -0.95) (settings focus-set -0.95) (slider focus-set -0.95)
      (firing tracking -0.95) (firing phaser-shoot -0.95) (firing phaser-check-status -0.95)
      (tracking phaser-shoot -0.95) (tracking phaser-check-status -0.95)
      (phaser-shoot phaser-check-status -0.95)
      (tracking2 click-main-control-phaser -0.7)


      (do-phaser power-connected -1) (do-phaser charge -1) (do-phaser stop-charging -1) (do-phaser power-connected2 -1) (do-phaser settings -1) (do-phaser slider -1) (do-phaser focus-set -1) (do-phaser firing -1) (do-phaser tracking -1) (do-phaser phaser-shoot -1) (do-phaser phaser-check-status -1) (do-phaser tracking2 -1) (do-phaser click-main-control-phaser -1)
      (charge-phaser set-focus -1) (charge-phaser fire-phaser -1) (charge-phaser main-control-phaser -1) (set-focus fire-phaser -1) (set-focus main-control-phaser -1) (fire-phaser main-control-phaser -1)
      (charge-phaser settings -1) (charge-phaser slider -1) (charge-phaser focus-set -1) (charge-phaser firing -1) (charge-phaser tracking -1) (charge-phaser phaser-shoot -1) (charge-phaser phaser-check-status -1) (charge-phaser tracking2 -1) (charge-phaser click-main-control-phaser -1)
      	(power-connected settings -1) (power-connected slider -1) (power-connected focus-set -1) (power-connected firing -1) (power-connected tracking -1) (power-connected phaser-shoot -1) (power-connected phaser-check-status -1) (power-connected tracking2 -1) (power-connected click-main-control-phaser -1)
      	(charge settings -1) (charge slider -1) (charge focus-set -1) (charge firing -1) (charge tracking -1) (charge phaser-shoot -1) (charge phaser-check-status -1) (charge tracking2 -1) (charge click-main-control-phaser -1)
      	(stop-charging settings -1) (stop-charging slider -1) (stop-charging focus-set -1) (stop-charging firing -1) (stop-charging tracking -1) (stop-charging phaser-shoot -1) (stop-charging phaser-check-status -1) (stop-charging tracking2 -1) (stop-charging click-main-control-phaser -1)
      	(power-connected2 settings -1) (power-connected2 slider -1) (power-connected2 focus-set -1) (power-connected2 firing -0.7) (power-connected2 tracking -1) (power-connected2 phaser-shoot -1) (power-connected2 phaser-check-status -1) (power-connected2 tracking2 -1) (power-connected2 click-main-control-phaser -1)
      (set-focus power-connected -1) (set-focus charge -1) (set-focus stop-charging -1) (set-focus power-connected2 -1) (set-focus firing -1) (set-focus tracking -1) (set-focus phaser-shoot -1) (set-focus phaser-check-status -1) (set-focus tracking2 -1) (set-focus click-main-control-phaser -1)
      	(settings firing -1) (settings tracking -1) (settings phaser-shoot -1) (settings phaser-check-status -1) (settings tracking2 -1) (settings click-main-control-phaser -1)
      	(slider firing -1) (slider tracking -1) (slider phaser-shoot -1) (slider phaser-check-status -1) (slider tracking2 -1) (slider click-main-control-phaser -1)
      	(focus-set firing -1) (focus-set tracking -1) (focus-set phaser-shoot -1) (focus-set phaser-check-status -1) (focus-set tracking2 -1) (focus-set click-main-control-phaser -1)
      (fire-phaser power-connected -1) (fire-phaser charge -1) (fire-phaser stop-charging -1) (fire-phaser power-connected2 -1) (fire-phaser settings -1) (fire-phaser slider -1) (fire-phaser focus-set -1) (fire-phaser click-main-control-phaser -1)
      	(firing click-main-control-phaser -1)
      	(tracking click-main-control-phaser -1)
      	(phaser-shoot click-main-control-phaser -1)
      	(phaser-check-status click-main-control-phaser -1)
      (main-control-phaser power-connected -1) (main-control-phaser charge -1) (main-control-phaser stop-charging -1) (main-control-phaser power-connected2 -1) (main-control-phaser settings -1) (main-control-phaser slider -1) (main-control-phaser focus-set -1) (main-control-phaser firing -1) (main-control-phaser tracking -1) (main-control-phaser phaser-shoot -1) (main-control-phaser tracking2 -1) (main-control-phaser phaser-check-status -1)
      

   (transporter-goal do-transporter -0.95) (transporter-goal scan -0.95) (transporter-goal frequency -0.95) (transporter-goal power -0.95) (transporter-goal main-control-transporter -0.95)
   (jammer-goal do-jammer -0.95) (jammer-goal scan -0.95) (jammer-goal frequency -0.95) (jammer-goal power -0.95) (jammer-goal main-control-transporter -0.95)
   (do-transporter scan -0.95) (do-transporter frequency -0.95) (do-transporter power -0.95) (do-transporter main-control-transporter -0.95)
   (do-jammer scan -0.95) (do-jammer frequency -0.95) (do-jammer power -0.95) (do-jammer main-control-transporter -0.95)
   	(scan scanner-on -0.95) (scan active-scan -0.95) (scan lock-signal -0.95) (scan scanner-off -0.95) 
        (scanner-on active-scan -0.75) (scanner-on lock-signal -0.85) (scanner-on scanner-off -0.85) (active-scan lock-signal -0.9) (active-scan scanner-off -0.9) (lock-signal scanner-off -0.72)
      (frequency enter-frequency -0.95) (frequency type-frequency -0.95) (frequency accept-frequency -0.95) (enter-frequency type-frequency -0.95) (enter-frequency accept-frequency -0.95) (type-frequency accept-frequency -0.95)
      (power transporter-power -0.95) (power synchronous-mode -0.95) (power transporter-shoot -0.95) 
      (transporter-power synchronous-mode -0.95) (transporter-power transporter-shoot -0.95)  (transporter-power transporter-check-status -0.95) (synchronous-mode transporter-shoot -0.95)   
      (main-control-transporter synchronous-mode2 -0.95) (main-control-transporter transporter-check-status -0.95) (main-control-transporter click-main-control-transporter -0.95)
      (synchronous-mode2 transporter-check-status -0.95) (synchronous-mode2 click-main-control-transporter -0.9) (transporter-check-status click-main-control-transporter -0.95)

      (do-transporter scanner-on -1) (do-transporter active-scan -1) (do-transporter lock-signal -1) (do-transporter scanner-off -1) (do-transporter enter-frequency -1) (do-transporter type-frequency -1) (do-transporter accept-frequency -1) (do-transporter transporter-power -1) (do-transporter synchronous-mode -1) (do-transporter transporter-shoot -1) (do-transporter synchronous-mode2 -1) (do-transporter transporter-check-status -1) (do-transporter click-main-control-transporter -1)
      (do-jammer scanner-on -1) (do-jammer active-scan -1) (do-jammer lock-signal -1) (do-jammer scanner-off -1) (do-jammer enter-frequency -1) (do-jammer type-frequency -1) (do-jammer accept-frequency -1) (do-jammer transporter-power -1) (do-jammer synchronous-mode -1) (do-jammer transporter-shoot -1) (do-jammer synchronous-mode2 -1) (do-jammer transporter-check-status -1) (do-jammer click-main-control-transporter -1)
      (scan enter-frequency -1) (scan type-frequency -1) (scan accept-frequency -1) (scan transporter-power -1) (scan synchronous-mode -1) (scan transporter-shoot -1) (scan synchronous-mode2 -1) (scan transporter-check-status -1) (scan click-main-control-transporter -1)
      (scanner-on enter-frequency -0.9) (scanner-on type-frequency -1) (scanner-on accept-frequency -1) (scanner-on transporter-power -1) (scanner-on synchronous-mode -1) (scanner-on transporter-shoot -1) (scanner-on synchronous-mode2 -1) (scanner-on transporter-check-status -1) (scanner-on click-main-control-transporter -1)
      (active-scan enter-frequency -0.9) (active-scan type-frequency -1) (active-scan accept-frequency -1) (active-scan transporter-power -1) (active-scan synchronous-mode -1) (active-scan transporter-shoot -1) (active-scan synchronous-mode2 -1) (active-scan transporter-check-status -1) (active-scan click-main-control-transporter -1)
      (lock-signal enter-frequency -0.9) (lock-signal type-frequency -1) (lock-signal accept-frequency -1) (lock-signal transporter-power -1) (lock-signal synchronous-mode -1) (lock-signal transporter-shoot -1) (lock-signal synchronous-mode2 -1) (lock-signal transporter-check-status -1) (lock-signal click-main-control-transporter -1)
      (scanner-off enter-frequency -0.7) (scanner-off type-frequency -1) (scanner-off accept-frequency -1) (scanner-off transporter-power -1) (scanner-off synchronous-mode -1) (scanner-off transporter-shoot -1) (scanner-off synchronous-mode2 -1) (scanner-off transporter-check-status -1) (scanner-off click-main-control-transporter -1)
      (frequency transporter-power -1) (frequency synchronous-mode -1) (frequency transporter-shoot -1) (frequency synchronous-mode2 -1) (frequency transporter-check-status -1) (frequency click-main-control-transporter -1)
      (enter-frequency transporter-power -1) (enter-frequency synchronous-mode -1) (enter-frequency transporter-shoot -1) (enter-frequency synchronous-mode2 -1) (enter-frequency transporter-check-status -1) (enter-frequency click-main-control-transporter -1)
      (type-frequency transporter-power -1) (type-frequency synchronous-mode -1) (type-frequency transporter-shoot -1) (type-frequency synchronous-mode2 -1) (type-frequency transporter-check-status -1) (type-frequency click-main-control-transporter -1)
      (accept-frequency transporter-power -1) (accept-frequency synchronous-mode -1) (accept-frequency transporter-shoot -1) (accept-frequency synchronous-mode -1) (accept-frequency transporter-check-status -1) (accept-frequency click-main-control-transporter -1)
      (power synchronous-mode2 -1) (power transporter-check-status -1) (power click-main-control-transporter -1)
      (transporter-power synchronous-mode2 -1) (transporter-power transporter-check-status -1) (transporter-power click-main-control-transporter -1)
      (synchronous-mode synchronous-mode2 -1) (synchronous-mode transporter-check-status -1) (synchronous-mode click-main-control-transporter -1)
      (transporter-shoot synchronous-mode2 -1) (transporter-shoot transporter-check-status -1) (transporter-shoot click-main-control-transporter -1)
      (transporter-shoot click-main-control-transporter -1)
      (transporter-check-status click-main-control-transporter -1)
      ) ;; set-similarities closing parenthesis

     (add-sji
      (intervene-jammer-scanner-on scanner-on 1.6) (scanner-on intervene-jammer-scanner-on 1.6)
      (intervene-jammer-lock-signal lock-signal 1.6) (lock-signal intervene-jammer-lock-signal 1.6)
      (intervene-jammer-enter-frequency enter-frequency 1.6) (enter-frequency intervene-jammer-enter-frequency 1.6)
      (intervene-jammer-scanner-off scanner-off 1.6) (scanner-off intervene-jammer-scanner-off 1.6)
      (intervene-jammer-active-scan active-scan 1.6) (active-scan intervene-jammer-active-scan 1.6)

      (intervene-jammer-scanner-on lock-signal 0.4) (lock-signal intervene-jammer-scanner-on 0.4)
      (intervene-jammer-scanner-on enter-frequency 0.4) (enter-frequency intervene-jammer-scanner-on 0.4)
      (intervene-jammer-scanner-on scanner-off 0.4) (scanner-off intervene-jammer-scanner-on 0.4)
      (intervene-jammer-scanner-on active-scan 0.4) (active-scan intervene-jammer-scanner-on 0.4)
      (intervene-jammer-lock-signal scanner-on 0.4) (scanner-on intervene-jammer-lock-signal 0.4)
      (intervene-jammer-lock-signal enter-frequency 0.4) (enter-frequency intervene-jammer-lock-signal 0.4)
      (intervene-jammer-lock-signal scanner-off 0.4) (scanner-off intervene-jammer-lock-signal 0.4)
      (intervene-jammer-lock-signal active-scan 0.4) (active-scan intervene-jammer-lock-signal 0.4)
      (intervene-jammer-enter-frequency scanner-on 0.4) (scanner-on intervene-jammer-enter-frequency 0.4)
      (intervene-jammer-enter-frequency lock-signal 0.4) (lock-signal intervene-jammer-enter-frequency 0.4)
      (intervene-jammer-enter-frequency scanner-off 0.4) (scanner-off intervene-jammer-enter-frequency 0.4)
      (intervene-jammer-enter-frequency active-scan 0.4) (active-scan intervene-jammer-enter-frequency 0.4)
      (intervene-jammer-scanner-off scanner-on 0.4) (scanner-on intervene-jammer-scanner-off 0.4)
      (intervene-jammer-scanner-off lock-signal 0.4) (lock-signal intervene-jammer-scanner-off 0.4)
      (intervene-jammer-scanner-off enter-frequency 0.4) (enter-frequency intervene-jammer-scanner-off 0.4)
      (intervene-jammer-scanner-off active-scan 0.4) (active-scan intervene-jammer-scanner-off 0.4)
      (intervene-jammer-active-scan scanner-on 0.4) (scanner-on intervene-jammer-active-scan 0.4)
      (intervene-jammer-active-scan lock-signal 0.4) (lock-signal intervene-jammer-active-scan 0.4)
      (intervene-jammer-active-scan enter-frequency 0.4) (enter-frequency intervene-jammer-active-scan 0.4)
      (intervene-jammer-active-scan scanner-off 0.4) (scanner-off intervene-jammer-active-scan 0.4)
      ) ;; add-aji closing parenthesis

  (start-hand-at-mouse)
  
  
  
  
  
#|
(defun generic-rfm-productions0 ())
|#


(p retrieve
   ?aural-location>
	buffer empty
   =goal>
   	isa star-trek-goal
	state-global =nn
        state-local retrieve
        - state-micro =nn 
        state-micro =sm
   ?manual>
	state free
   ?retrieval>
   	state free
==>
   +retrieval>
   	isa find-button 
   	node-name =nn
        - node-name =sm
   =goal>
   	state-local find
)

(p post-error-retrieve-the-same
   =aural-location>
	isa audio-event
	kind wrong-click-buzzer
   =goal>
   	isa star-trek-goal
	state-global =nn
        state-local retrieve
        - state-micro =nn 
        state-micro =sm
   ?manual>
	state free
   ?retrieval>
   	state free
==>
   +retrieval>
   	isa find-button 
   	node-name =nn
        - node-name =sm
   =goal>
   	state-local find
 )

(p post-error-retrieve-something-else
   =aural-location>
	isa audio-event
	kind wrong-click-buzzer
   =goal>
   	isa star-trek-goal
	state-global =nn
        state-local retrieve
        - state-micro =nn 
        state-micro =sm
   =imaginal>
	isa problem-state
        interface =i
   ?retrieval>
	state free
==>
   =goal>
	state-local find
   +retrieval>
   	isa find-button 
        interface =i
   	- node-name =nn
)

(p find
   =goal>
   	isa star-trek-goal
        state-local find
   =retrieval>
   	isa find-button
        node-name =nn
        xcor1       =x1
        xcor2       =x2
        ycor1       =y1
        ycor2       =y2
        kind =k
        color =c
==>
   +visual-location>
      ISA         visual-location
      screen-x    (within =x1 =x2)
      screen-y    (within =y1 =y2)
      kind =k
      color =c
   =goal>
   	state-local move
)


(p move-mouse-cursor
   =goal>
	isa star-trek-goal
        state-local move
   =visual-location>
	isa visual-location
        - kind text
        - value blip
   =retrieval>
	isa find-button
   ?manual>
	preparation free
==>
   =goal>
	state-local click
   +manual>
	isa move-cursor
        loc =visual-location
;; !eval! (buffer-chunk visual-location)
)

(p find-visual-location-failure-retrieve-the-same
   =goal>
	isa star-trek-goal
        state-global =nn
        state-local move
        state-micro =sm
   ?visual-location>
	state error
==>
   +retrieval>
   	isa find-button 
   	node-name =nn
        - node-name =sm
   =goal>
   	state-local find
 )

(p find-visual-location-failure-retrieve-something-else
   =goal>
	isa star-trek-goal
        state-global =nn
        state-local move
   =imaginal>
	isa problem-state
        interface =i
   ?visual-location>
	state error
==>
   =goal>
	state-local find
   +retrieval>
   	isa find-button 
        interface =i
   	- node-name =nn
)


(p move-visual-attention-text
   =goal>
	isa star-trek-goal
        state-local move
   =visual-location>
	isa visual-location
        kind text
   =retrieval>
	isa find-button
   ?visual>
	state free
==>
   =goal>
	state-local read
   +visual>
	isa move-attention
	screen-pos =visual-location
;; !eval! (buffer-chunk visual-location)
)

(p move-visual-attention-blip
   =goal>
	isa star-trek-goal
        state-local move
   =visual-location>
	isa visual-location
        kind visual-object
        value blip
   =retrieval>
	isa find-button
   ?visual>
	state free
==>
   =goal>
	state-local blip
   +visual>
	isa move-attention
	screen-pos =visual-location
;; !eval! (buffer-chunk visual-location)
)

(p click
   =goal>
	isa star-trek-goal
        state-local click
   ?manual>
	preparation free
==>
   +manual>
	isa click-mouse
   =goal>
	state-local verify
   )

(p verify-a-buzzer
   =aural-location>
	isa audio-event
	kind wrong-click-buzzer
   =goal>
	isa star-trek-goal
        state-local verify
        state-global =nn
   =imaginal>
	isa problem-state
        interface =i
   ?manual>
	state free
   ?retrieval>
	state free
==>
   =goal>
	state-local retrieve
   =aural-location>
   )

(p retrieval-error-try-again
   =goal>
	isa star-trek-goal
    =imaginal>
	isa problem-state
        bottom =nn
   ?retrieval>
	state error
==>
   +retrieval>
	isa find-button
        node-name =nn
   =goal>
	state-local find
        )




  ;;;;;;;;;;;;;;;;;;;;;;;;;;  
  ;;; phaser-trained-intervening-subtask
  ;;;;;;;;;;;;;;;;;;;;;;;;;;
  
  #|
(defun phaser0)
|#

(p power-connected1-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name power-connected
        color light-gray
==>
   =goal>
	state-global charge
        state-local retrieve
   =imaginal>
	bottom charge
        middle charge-phaser
   )

(p charge-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name charge
==>
   =goal>
	state-global settings
        state-local retrieve
   =imaginal>
	bottom settings
        middle set-focus
   )

(p settings-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name settings
==>
   =goal>
	state-global slider
        state-local retrieve
   =imaginal>
	bottom slider
        middle set-focus
   )

(p slider-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name slider
==>
   =goal>
	state-global focus-set
        state-local retrieve
   =imaginal>
	bottom focus-set
        middle set-focus
   )

(p focus-set-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name focus-set
==>
   =goal>
	state-global stop-charging
        state-local retrieve
   =imaginal>
	bottom stop-charging
        middle charge-phaser
   )

(p stop-charging-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name stop-charging
==>
   =goal>
	state-global power-connected2
        state-local retrieve
   =imaginal>
	bottom power-connected2
        middle charge-phaser
   )

(p power-connected2-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name power-connected2
        color blue
==>
   =goal>
	state-global firing
        state-local retrieve
   =imaginal>
	bottom firing
        middle fire-phaser
   )

(p firing-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name firing
==>
   =goal>
	state-global tracking
        state-local retrieve
   =imaginal>
	bottom tracking
        middle fire-phaser
   )

(p tracking-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name tracking
==>
   =goal>
	state-global phaser-shoot
        state-local retrieve
   =imaginal>
	bottom phaser-shoot
        middle fire-phaser
   )

(p phaser-shoot-act
   =goal>
   	isa star-trek-goal
        state-local blip
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name phaser-shoot
   ?manual>
	preparation free
==>
   +manual>
	isa punch
        hand left
        finger thumb
   =goal>
        state-local verify
   )

(p phaser-shoot-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name phaser-shoot
==>
   =goal>
	state-global phaser-check-status
        state-local retrieve
   =imaginal>
	bottom phaser-check-status
        middle fire-phaser
   )

(p romulans-not-destroyed
   =goal>
	isa star-trek-goal
        state-local read
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name phaser-check-status
   =visual-location>
	isa visual-location
        kind text
   =visual>
	isa text
   	- value "destroyed"
==>
   =goal>
	state-global power-connected
   	state-local retrieve
   =imaginal>
	middle charge-phaser
        bottom power-connected)

(p romulans-destroyed
   =goal>
	isa star-trek-goal
        state-local read
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name phaser-check-status
   =visual-location>
	isa visual-location
        kind text
   =visual>
	isa text
   	value "destroyed"
==>
   =goal>
	state-global tracking2
        state-local retrieve
   =imaginal>
	middle main-control-phaser
        bottom tracking2)

(p tracking2-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name tracking2
==>
   =goal>
	state-global click-main-control-phaser
	state-local retrieve
   =imaginal>
	middle main-control-phaser
	bottom click-main-control-phaser
   )

(p click-main-control-phaser-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name click-main-control-phaser
==>
   =goal>
	state-global finished-task
        state-local nil
   =imaginal>
	bottom finished-task
   )



#|
(defun transporter0)
|#

(p scanner-on-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name scanner-on
==>
   =goal>
	state-global active-scan
        state-local retrieve
   =imaginal>
	bottom active-scan)

(p active-scan-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name active-scan
==>
   =goal>
	state-global lock-signal
        state-local retrieve
   =imaginal>
	bottom lock-signal)

(p lock-signal-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name lock-signal
==>
   =goal>
	state-global scanner-off
        state-local retrieve
   =imaginal>
	bottom scanner-off)

(p transporter-scanner-off-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name scanner-off
==>
   =goal>
	state-global enter-frequency
        state-local retrieve
   =imaginal>
	bottom enter-frequency
        middle frequency)

(p enter-frequency-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name enter-frequency
==>
   =goal>
	state-global type-frequency
        state-local retrieve
   =imaginal>
	bottom type-frequency)

(p type-frequency-act
   =goal>
   	isa star-trek-goal
        state-local read
   =imaginal>
	isa problem-state
   =visual-location>
	isa visual-location
        kind text
   =retrieval>
	isa type
        node-name type-frequency
        key =k
   ?manual>
	preparation free
==>
   +manual>
	isa press-key
	key =k
   =goal>
        state-local type-again)

(p type-frequency-click2
   =goal>
	isa star-trek-goal
        state-local type-again
   =imaginal>
	isa problem-state
   =retrieval>
	isa type
        node-name type-frequency
        key =k
   ?manual>
	preparation free
==>
   +manual>
	isa press-key
	key =k
   =goal>
        state-local verify
    )

(p type-frequency-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name type-frequency
==>
   =goal>
	state-global accept-frequency
        state-local retrieve
   =imaginal>
	bottom accept-frequency)

(p accept-frequency-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name accept-frequency
==>
   =goal>
	state-global transporter-power
        state-local retrieve
   =imaginal>
	middle power
        bottom transporter-power)

(p transporter-power-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name transporter-power
==>
   =goal>
	state-global synchronous-mode
        state-local retrieve
   =imaginal>
	bottom synchronous-mode)

(p synchronous-mode1-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name synchronous-mode
==>
   =goal>
	state-global transporter-shoot
        state-local retrieve
   =imaginal>
	bottom transporter-shoot)

(p transporter-shoot-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name transporter-shoot
==>
   =goal>
	state-global synchronous-mode2
        state-local retrieve
   =imaginal>
	middle main-control-transporter
        bottom synchronous-mode2)

(p synchronous-mode2-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name synchronous-mode2
==>
   =goal>
	state-global transporter-check-status
        state-local retrieve
   =imaginal>
	bottom transporter-check-status)

(p transporter-beam-failed
   =goal>
	isa star-trek-goal
        state-local read
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name transporter-check-status
   =visual-location>
	isa visual-location
        kind text
   =visual>
	isa text
   	- value "successful"
==>
   =goal>
	state-global scanner-on
   	state-local retrieve
   =imaginal>
	middle scan
        bottom scanner-on)

(p beam-successful
   =goal>
	isa star-trek-goal
        state-local read
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name transporter-check-status
   =visual-location>
	isa visual-location
        kind text
   =visual>
	isa text
   	value "successful"
==>
   =goal>
	state-global click-main-control-transporter
        state-local retrieve
   =imaginal>
	middle main-control-transporter
        bottom click-main-control-transporter)

(p click-main-control-transporter-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name click-main-control-transporter
==>
   =goal>
	state-global finished-task
        state-local nil
   =imaginal>
	bottom finished-task)






;;;;;;;;;;;;;;;;;;;;;;;;;;  
;;; jammer-trained-scanner-reordering
;;; (:active-scan :scanner-off :lock-signal :scanner-on)
;;;;;;;;;;;;;;;;;;;;;;;;;;

#|
(defun jammer0)
|#

(p flagged-step-jammer
   =goal>
	isa star-trek-goal
        state-global =nn
        state-local retrieve
        state-micro =nn
   =imaginal>
	isa problem-state
        top do-changed-jammer
   ?retrieval>
	state free
==>
   +retrieval>
	isa change-instruction
        current-flag =nn
   =goal>
        state-local retrieve-change-instruction
        )

(p got-change-instruction-jammer
   =goal>
	isa star-trek-goal
        state-local retrieve-change-instruction
   =imaginal>
	isa problem-state
        top do-changed-jammer
   =retrieval>
	isa change-instruction
        current-flag =nn
        do-step =new-nn
        do-subtask =new-st
        next-flag =nf
==>
   =goal>
	state-global =new-nn
        state-local retrieve
        state-micro =nf
        )

(p post-error-retrieve-change-instruction-again
   =aural-location>
	isa audio-event
	kind wrong-click-buzzer
   =goal>
   	isa star-trek-goal
	- state-global =nn
        state-local retrieve
   =imaginal>
	isa problem-state
        top do-changed-jammer
        bottom =nn 
   ?manual>
	state free
   ?retrieval>
   	state free
==>
   +retrieval>
	isa change-instruction
        current-flag =nn
   =goal>
        state-local retrieve-change-instruction
        state-global =nn
        state-micro =nn
 )







   
#|
(defun spp0)
|#
  
(spp 
 (post-error-retrieve-something-else :u -10)
 (post-error-retrieve-change-instruction-again :u 11)
 )
  
  
  (setf *actr-enabled-p* t)
  
  ;; define-model closing parenthesis
  )


   












(define-model fdm1
  
  (sgp-fct (list
   ;; model debugging & running
   :v *v* :trace-detail 'low :show-focus nil
   ;; central parameters
   :er t :esc t :ol 4
   ;; procedural
   :crt nil :cst nil
   ;; utility
   :ul t :egs *egs* ;; :iu 20 ;:ut -150 
   ;; visual
   :do-not-harvest 'visual-location 
   :do-not-harvest 'visual 
   :do-not-harvest 'retrieval 
   :do-not-harvest 'imaginal 
   ;; :auto-attend t 
   ;; declarative module
   :mp *mp* :md -10 :ans *ans* :mas *mas* :rt *rt* ;; :blc 2 
   ;; :declarative-num-finsts 20 :declarative-finst-span 30.0 
   ;; :act t 
   ;; buffer-params
   ;; :imaginal-activation 1.0
   ))
  
  (chunk-type star-trek-goal state-micro state-local state-global wm-dummy1 wm-dummy2 wm-dummy3) ;; wmd4)
  (chunk-type schema interface node-name child1 child2 child3 child4)
  (chunk-type find-button interface node-name xcor1 xcor2 ycor1 ycor2 kind value color)
  (chunk-type (type (:include find-button)) key)
  (chunk-type (check-status (:include find-button)))
  (chunk-type wm-dummy value)
  (chunk-type problem-state interface top middle bottom)
  (chunk-type change-instruction current-flag do-step do-subtask next-flag)
  
  (add-dm
   
   (finished-experiment isa star-trek-goal state-global finished-experiment state-local finished-experiment state-micro finished-experiment)
   
   
   (phaser-goal isa star-trek-goal state-global power-connected state-local retrieve state-micro nothing wm-dummy1 wm-dummy-chunk1 wm-dummy2 wm-dummy-chunk2 wm-dummy3 wm-dummy-chunk3) ;; wmd4 wmd-chunk4)
   (phaser-imaginal isa problem-state interface phaser top do-phaser middle charge-phaser bottom power-connected)
   (do-phaser isa schema interface phaser node-name do-phaser child1 charge-phaser child2 set-focus child3 firing child4 main-control-phaser)
   	(charge-phaser isa schema interface phaser node-name charge-phaser child1 power-connected child2 charge child3 stop-charging child4 power-connected2)
   		(power-connected isa find-button interface phaser node-name power-connected  xcor1 690 xcor2 730 ycor1 190 ycor2 220 kind visual-object value box color light-gray)
   		(charge isa find-button interface phaser node-name charge  xcor1 720 xcor2 760 ycor1 130 ycor2 160 kind oval value oval color light-gray)
   		(stop-charging isa find-button interface phaser node-name stop-charging  xcor1 720 xcor2 760 ycor1 260 ycor2 300 kind oval value oval color light-gray)
   		(power-connected2 isa find-button interface phaser node-name power-connected2  xcor1 690 xcor2 730 ycor1 190 ycor2 220 kind visual-object value box color blue)
   	(set-focus isa schema interface phaser node-name set-focus child1 focus child2 slider child3 focus-set child4 NOTHING)
   		(settings isa find-button interface phaser node-name settings  xcor1 470 xcor2 490 ycor1 590 ycor2 610 kind oval value oval color light-gray)
   		(slider isa find-button interface phaser node-name slider  xcor1 570 xcor2 620 ycor1 620 ycor2 680 kind visual-object value box color black)
   		(focus-set isa find-button interface phaser node-name focus-set  xcor1 580 xcor2 640 ycor1 570 ycor2 630 kind visual-object value box color light-gray)
   	(fire-phaser isa schema interface phaser node-name fire-phaser child1 firing child2 tracking child3 phaser-shoot child4 phasercheck-status)
  		(firing isa find-button interface phaser node-name firing  xcor1 120 xcor2 180 ycor1 380 ycor2 440 kind oval value oval color light-gray)
   		(tracking isa find-button interface phaser node-name tracking  xcor1 300 xcor2 360 ycor1 380 ycor2 440 kind oval value oval color light-gray)
                (phaser-shoot isa type interface phaser node-name phaser-shoot  xcor1 230 xcor2 290 ycor1 200 ycor2 260 kind visual-object value blip color black key space)
   		(phaser-check-status isa check-status interface phaser node-name phaser-check-status  xcor1 135 xcor2 175 ycor1 630 ycor2 670 kind text value text color black)
   	(main-control-phaser isa schema interface phaser node-name main-control-phaser child1 tracking2 child2 click-main-control-phaser child3 NOTHING child4 NOTHING)
   		(tracking2 isa find-button interface phaser node-name tracking2  xcor1 300 xcor2 360 ycor1 380 ycor2 440 kind oval value oval color light-gray)
   		(click-main-control-phaser isa find-button interface phaser node-name click-main-control-phaser  xcor1 780 xcor2 910 ycor1 570 ycor2 640 kind oval value oval color light-gray)

   
   (transporter-goal isa star-trek-goal state-global scanner-on state-local retrieve state-micro nothing wm-dummy1 wm-dummy-chunk1 wm-dummy2 wm-dummy-chunk2 wm-dummy3 wm-dummy-chunk3)
   (transporter-imaginal isa problem-state interface transporter top do-transporter middle scan bottom scanner-on)
   (do-transporter isa schema interface transporter node-name do-transporter child1 scan child2 frequency child3 power child4 main-control-transporter)
   	(scan isa schema interface transporter node-name scan child1 scanner-on child2 active-scan child3 lock-signal child4 scanner-off)
   		(scanner-on isa find-button interface transporter node-name scanner-on  xcor1 690 xcor2 730 ycor1 260 ycor2 280 kind oval value oval color light-gray)
   		(active-scan isa find-button interface transporter node-name active-scan  xcor1 690 xcor2 730 ycor1 300 ycor2 320 kind oval value oval color light-gray)
		(lock-signal isa find-button interface transporter node-name lock-signal  xcor1 690 xcor2 730 ycor1 320 ycor2 340 kind oval value oval color light-gray)
   		(scanner-off isa find-button interface transporter node-name scanner-off  xcor1 690 xcor2 730 ycor1 280 ycor2 300 kind oval value oval color light-gray)
   	(frequency isa schema interface transporter node-name frequency child1 enter-frequency child2 type child3 accept-frequency child4 nothing)
   		(enter-frequency isa find-button interface transporter node-name enter-frequency  xcor1 500 xcor2 530 ycor1 145 ycor2 175 kind oval value oval color light-gray)
   		(type-frequency isa type interface transporter node-name type-frequency  xcor1 460 xcor2 490 ycor1 185 ycor2 215 kind text value nothing color black key 5)
                (accept-frequency isa find-button interface transporter node-name accept-frequency  xcor1 435 xcor2 465 ycor1 215 ycor2 245 kind visual-object value box color light-gray)
        (power isa schema interface transporter node-name power child1 transporter-power child2 synchronous-mode child3 transporter-shoot child4 nothing)
        	(transporter-power isa find-button interface transporter node-name transporter-power  xcor1 185 xcor2 215 ycor1 215 ycor2 245 kind visual-object value box color light-gray)
                (synchronous-mode isa find-button interface transporter node-name synchronous-mode  xcor1 245 xcor2 275 ycor1 145 ycor2 175 kind oval value oval color light-gray)
                (transporter-shoot isa find-button interface transporter node-name transporter-shoot  xcor1 120 xcor2 450 ycor1 350 ycor2 700 kind visual-object value unknown color black)
        (main-control-transporter isa schema interface transporter node-name main-control-transporter child1 synchronous-mode2 child2 transporter-check-status child3 click-main-control-transporter child4 nothing)
                (synchronous-mode2 isa find-button interface transporter node-name synchronous-mode2  xcor1 245 xcor2 275 ycor1 145 ycor2 175 kind oval value oval color light-gray)
   		(transporter-check-status isa find-button interface transporter node-name transporter-check-status  xcor1 530 xcor2 800 ycor1 460 ycor2 500 kind text value nothing color black)
        	(click-main-control-transporter isa find-button interface transporter node-name click-main-control-transporter  xcor1 545 xcor2 575 ycor1 580 ycor2 610 kind oval value oval color light-gray)
    


  ;;; (frequency, scanner, power, shoot)
   (jammer-goal isa star-trek-goal state-global scanner-on state-local retrieve state-micro nothing wm-dummy1 wm-dummy-chunk1 wm-dummy2 wm-dummy-chunk2 wm-dummy3 wm-dummy-chunk3)
   (jammer-imaginal isa problem-state interface transporter top do-jammer middle scan bottom scanner-on)
   (do-jammer isa schema interface transporter node-name do-jammer child1 frequency child2 scan child3 power child4 main-control-transporter)



   (wm-dummy-chunk1 isa wm-dummy value "a")
   (wm-dummy-chunk2 isa wm-dummy value "b")
   (wm-dummy-chunk3 isa wm-dummy value "c")
   (nothing isa wm-dummy value "nothing")
   
   )

  (sdp-fct '((power-connected2 :base-level -1.2) (tracking2 :base-level -1.1) (scanner-on :base-level -0.4) (scanner-off :base-level -0.4) (synchronous-mode2 :base-level -0.4)))

   (set-similarities
    (phaser-goal do-phaser -0.95) (phaser-goal charge-phaser -0.95) (phaser-goal set-focus -0.95) (phaser-goal fire-phaser -0.95) (phaser-goal main-control-phaser -0.95)
    (do-phaser charge-phaser -0.95) (do-phaser set-focus -0.95) (do-phaser fire-phaser -0.95) (do-phaser main-control-phaser -0.95)
   	(charge-phaser power-connected -0.95) (charge-phaser charge -0.95) (charge-phaser stop-charging -0.95) (charge-phaser power-connected2 -0.95)
      (set-focus settings -0.95) (set-focus slider -0.95) (set-focus focus-set -0.95)
      (fire-phaser firing -0.95) (fire-phaser tracking -0.95) (fire-phaser phaser-shoot -0.95) (fire-phaser phaser-check-status -0.95)
      (main-control-phaser click-main-control-phaser -0.95)
      (power-connected charge -0.95) (power-connected stop-charging -0.95) (power-connected power-connected2 -0.95)
      (charge stop-charging -0.95) (charge power-connected2 -0.95)
      (stop-charging power-connected2 -0.95)
      (settings slider -0.95) (settings focus-set -0.95) (slider focus-set -0.95)
      (firing tracking -0.95) (firing phaser-shoot -0.95) (firing phaser-check-status -0.95)
      (tracking phaser-shoot -0.95) (tracking phaser-check-status -0.95)
      (phaser-shoot phaser-check-status -0.95)
      (tracking2 click-main-control-phaser -0.7)

      (do-phaser power-connected -1) (do-phaser charge -1) (do-phaser stop-charging -1) (do-phaser power-connected2 -1) (do-phaser settings -1) (do-phaser slider -1) (do-phaser focus-set -1) (do-phaser firing -1) (do-phaser tracking -1) (do-phaser phaser-shoot -1) (do-phaser phaser-check-status -1) (do-phaser tracking2 -1) (do-phaser click-main-control-phaser -1)
      (charge-phaser set-focus -1) (charge-phaser fire-phaser -1) (charge-phaser main-control-phaser -1) (set-focus fire-phaser -1) (set-focus main-control-phaser -1) (fire-phaser main-control-phaser -1)
      (charge-phaser settings -1) (charge-phaser slider -1) (charge-phaser focus-set -1) (charge-phaser firing -1) (charge-phaser tracking -1) (charge-phaser phaser-shoot -1) (charge-phaser phaser-check-status -1) (charge-phaser tracking2 -1) (charge-phaser click-main-control-phaser -1)
      	(power-connected settings -1) (power-connected slider -1) (power-connected focus-set -1) (power-connected firing -1) (power-connected tracking -1) (power-connected phaser-shoot -1) (power-connected phaser-check-status -1) (power-connected tracking2 -1) (power-connected click-main-control-phaser -1)
      	(charge settings -1) (charge slider -1) (charge focus-set -1) (charge firing -1) (charge tracking -1) (charge phaser-shoot -1) (charge phaser-check-status -1) (charge tracking2 -1) (charge click-main-control-phaser -1)
      	(stop-charging settings -1) (stop-charging slider -1) (stop-charging focus-set -1) (stop-charging firing -1) (stop-charging tracking -1) (stop-charging phaser-shoot -1) (stop-charging phaser-check-status -1) (stop-charging tracking2 -1) (stop-charging click-main-control-phaser -1)
      	(power-connected2 settings -0.7) (power-connected2 slider -1) (power-connected2 focus-set -1) (power-connected2 firing -1) (power-connected2 tracking -1) (power-connected2 phaser-shoot -1) (power-connected2 phaser-check-status -1) (power-connected2 tracking2 -1) (power-connected2 click-main-control-phaser -1)
      (set-focus power-connected -1) (set-focus charge -1) (set-focus stop-charging -1) (set-focus power-connected2 -1) (set-focus firing -1) (set-focus tracking -1) (set-focus phaser-shoot -1) (set-focus phaser-check-status -1) (set-focus tracking2 -1) (set-focus click-main-control-phaser -1)
      	(settings firing -1) (settings tracking -1) (settings phaser-shoot -1) (settings phaser-check-status -1) (settings tracking2 -1) (settings click-main-control-phaser -1)
      	(slider firing -1) (slider tracking -1) (slider phaser-shoot -1) (slider phaser-check-status -1) (slider tracking2 -1) (slider click-main-control-phaser -1)
      	(focus-set firing -1) (focus-set tracking -1) (focus-set phaser-shoot -1) (focus-set phaser-check-status -1) (focus-set tracking2 -1) (focus-set click-main-control-phaser -1)
      (fire-phaser power-connected -1) (fire-phaser charge -1) (fire-phaser stop-charging -1) (fire-phaser power-connected2 -1) (fire-phaser settings -1) (fire-phaser slider -1) (fire-phaser focus-set -1) (fire-phaser click-main-control-phaser -1)
      	(firing click-main-control-phaser -1)
      	(tracking click-main-control-phaser -1)
      	(phaser-shoot click-main-control-phaser -1)
      	(phaser-check-status click-main-control-phaser -1)
      (tracking click-main-control-phaser -1)
      (main-control-phaser power-connected -1) (main-control-phaser charge -1) (main-control-phaser stop-charging -1) (main-control-phaser power-connected2 -1) (main-control-phaser settings -1) (main-control-phaser slider -1) (main-control-phaser focus-set -1) (main-control-phaser firing -1) (main-control-phaser tracking -1) (main-control-phaser phaser-shoot -1) (main-control-phaser tracking2 -1) (main-control-phaser phaser-check-status -1)
      

   (transporter-goal do-transporter -0.95) (transporter-goal scan -0.95) (transporter-goal frequency -0.95) (transporter-goal power -0.95) (transporter-goal main-control-transporter -0.95)
   (jammer-goal do-jammer -0.95) (jammer-goal scan -0.95) (jammer-goal frequency -0.95) (jammer-goal power -0.95) (jammer-goal main-control-transporter -0.95)
   (do-transporter scan -0.95) (do-transporter frequency -0.95) (do-transporter power -0.95) (do-transporter main-control-transporter -0.95)
   (do-jammer scan -0.95) (do-jammer frequency -0.95) (do-jammer power -0.95) (do-jammer main-control-transporter -0.95)
   	(scan scanner-on -0.95) (scan active-scan -0.95) (scan lock-signal -0.95) (scan scanner-off -0.95) (scanner-on active-scan -0.75) (scanner-on lock-signal -0.85) (scanner-on scanner-off -0.85) (active-scan lock-signal -0.9) (active-scan scanner-off -0.9) (lock-signal scanner-off -0.72)
      (frequency enter-frequency -0.95) (frequency type-frequency -0.95) (frequency accept-frequency -0.95) (enter-frequency type-frequency -0.95) (enter-frequency accept-frequency -0.95) (type-frequency accept-frequency -0.95)
      (power transporter-power -0.95) (power synchronous-mode -0.95) (power transporter-shoot -0.95)  (power transporter-check-status -0.95) 
      (transporter-power synchronous-mode -0.75) (transporter-power transporter-shoot -0.95)  (transporter-power transporter-check-status -0.95) (synchronous-mode transporter-shoot -0.95)   
      (main-control-transporter synchronous-mode2 -0.95) (main-control-transporter transporter-check-status -0.95) (main-control-transporter click-main-control-transporter -0.95)
      (synchronous-mode2 transporter-check-status -0.95) (synchronous-mode2 click-main-control-transporter -0.9) (transporter-check-status click-main-control-transporter -0.95)

      (do-transporter scanner-on -1) (do-transporter active-scan -1) (do-transporter lock-signal -1) (do-transporter scanner-off -1) (do-transporter enter-frequency -1) (do-transporter type-frequency -1) (do-transporter accept-frequency -1) (do-transporter transporter-power -1) (do-transporter synchronous-mode -1) (do-transporter transporter-shoot -1) (do-transporter synchronous-mode2 -1) (do-transporter transporter-check-status -1) (do-transporter click-main-control-transporter -1)
      (do-jammer scanner-on -1) (do-jammer active-scan -1) (do-jammer lock-signal -1) (do-jammer scanner-off -1) (do-jammer enter-frequency -1) (do-jammer type-frequency -1) (do-jammer accept-frequency -1) (do-jammer transporter-power -1) (do-jammer synchronous-mode -1) (do-jammer transporter-shoot -1) (do-jammer synchronous-mode2 -1) (do-jammer transporter-check-status -1) (do-jammer click-main-control-transporter -1)
      (scan enter-frequency -1) (scan type-frequency -1) (scan accept-frequency -1) (scan transporter-power -1) (scan synchronous-mode -1) (scan transporter-shoot -1) (scan synchronous-mode2 -1) (scan transporter-check-status -1) (scan click-main-control-transporter -1)
      (scanner-on enter-frequency -1) (scanner-on type-frequency -1) (scanner-on accept-frequency -1) (scanner-on transporter-power -1) (scanner-on synchronous-mode -1) (scanner-on transporter-shoot -1) (scanner-on synchronous-mode2 -1) (scanner-on transporter-check-status -1) (scanner-on click-main-control-transporter -1)
      (active-scan enter-frequency -1) (active-scan type-frequency -1) (active-scan accept-frequency -1) (active-scan transporter-power -1) (active-scan synchronous-mode -1) (active-scan transporter-shoot -1) (active-scan synchronous-mode2 -1) (active-scan transporter-check-status -1) (active-scan click-main-control-transporter -1)
      (lock-signal enter-frequency -1) (lock-signal type-frequency -1) (lock-signal accept-frequency -1) (lock-signal transporter-power -1) (lock-signal synchronous-mode -1) (lock-signal transporter-shoot -1) (lock-signal synchronous-mode2 -1) (lock-signal transporter-check-status -1) (lock-signal click-main-control-transporter -1)
      (scanner-off enter-frequency -0.7) (scanner-off type-frequency -1) (scanner-off accept-frequency -1) (scanner-off transporter-power -1) (scanner-off synchronous-mode -1) (scanner-off transporter-shoot -1) (scanner-off synchronous-mode2 -1) (scanner-off transporter-check-status -1) (scanner-off click-main-control-transporter -1)
      (frequency transporter-power -1) (frequency synchronous-mode -1) (frequency transporter-shoot -1) (frequency synchronous-mode2 -1) (frequency transporter-check-status -1) (frequency click-main-control-transporter -1)
      (enter-frequency transporter-power -1) (enter-frequency synchronous-mode -1) (enter-frequency transporter-shoot -1) (enter-frequency synchronous-mode2 -1) (enter-frequency transporter-check-status -1) (enter-frequency click-main-control-transporter -1)
      (type-frequency transporter-power -1) (type-frequency synchronous-mode -1) (type-frequency transporter-shoot -1) (type-frequency synchronous-mode2 -1) (type-frequency transporter-check-status -1) (type-frequency click-main-control-transporter -1)
      (accept-frequency transporter-power -1) (accept-frequency synchronous-mode -1) (accept-frequency transporter-shoot -1) (accept-frequency synchronous-mode2 -1) (accept-frequency transporter-check-status -1) (accept-frequency click-main-control-transporter -1)
      (transporter-power click-main-control-transporter -1)
      (synchronous-mode synchronous-mode2 -1) (synchronous-mode transporter-check-status -1) (synchronous-mode click-main-control-transporter -1)
      (transporter-shoot synchronous-mode2 -1) (transporter-shoot transporter-check-status -1) (transporter-shoot click-main-control-transporter -1)
      (transporter-shoot click-main-control-transporter -1)
      (transporter-check-status click-main-control-transporter -1)
      )


  (start-hand-at-mouse)
  
  
  
  
  
#|
(defun generic-rfm-productions1 ())
|#


(p retrieve
   ?aural-location>
	buffer empty
   =goal>
   	isa star-trek-goal
	state-global =nn
        state-local retrieve
        - state-micro =nn 
        state-micro =sm
   ?manual>
	state free
   ?retrieval>
   	state free
==>
   +retrieval>
   	isa find-button 
   	node-name =nn
        - node-name =sm
   =goal>
   	state-local find
)

(p post-error-retrieve-the-same
   =aural-location>
	isa audio-event
	kind wrong-click-buzzer
   =goal>
   	isa star-trek-goal
	state-global =nn
        state-local retrieve
        - state-micro =nn 
        state-micro =sm
   ?manual>
	state free
   ?retrieval>
   	state free
==>
   +retrieval>
   	isa find-button 
   	node-name =nn
        - node-name =sm
   =goal>
   	state-local find
 )

(p post-error-retrieve-something-else
   =aural-location>
	isa audio-event
	kind wrong-click-buzzer
   =goal>
   	isa star-trek-goal
	state-global =nn
        state-local retrieve
        - state-micro =nn 
        state-micro =sm
   =imaginal>
	isa problem-state
        interface =i
   ?retrieval>
	state free
==>
   =goal>
	state-local find
   +retrieval>
   	isa find-button 
        interface =i
   	- node-name =nn
)

(p find
   =goal>
   	isa star-trek-goal
        state-local find
   =retrieval>
   	isa find-button
        node-name =nn
        xcor1       =x1
        xcor2       =x2
        ycor1       =y1
        ycor2       =y2
        kind =k
        color =c
==>
   +visual-location>
      ISA         visual-location
      screen-x    (within =x1 =x2)
      screen-y    (within =y1 =y2)
      kind =k
      color =c
   =goal>
   	state-local move
)

(p move-mouse-cursor
   =goal>
	isa star-trek-goal
        state-local move
   =visual-location>
	isa visual-location
        - kind text
        - value blip
   =retrieval>
	isa find-button
   ?manual>
	preparation free
==>
   =goal>
	state-local click
   +manual>
	isa move-cursor
        loc =visual-location
)

(p find-visual-location-failure-retrieve-the-same
   =goal>
	isa star-trek-goal
        state-global =nn
        state-local move
        state-micro =sm
   ?visual-location>
	state error
==>
   +retrieval>
   	isa find-button 
   	node-name =nn
        - node-name =sm
   =goal>
   	state-local find
 )

(p find-visual-location-failure-retrieve-something-else
   =goal>
	isa star-trek-goal
        state-global =nn
        state-local move
   =imaginal>
	isa problem-state
        interface =i
   ?visual-location>
	state error
==>
   =goal>
	state-local find
   +retrieval>
   	isa find-button 
        interface =i
   	- node-name =nn
)	

(p move-visual-attention-text
   =goal>
	isa star-trek-goal
        state-local move
   =visual-location>
	isa visual-location
        kind text
   =retrieval>
	isa find-button
   ?visual>
	state free
==>
   =goal>
	state-local read
   +visual>
	isa move-attention
	screen-pos =visual-location
)

(p move-visual-attention-blip
   =goal>
	isa star-trek-goal
        state-local move
   =visual-location>
	isa visual-location
        kind visual-object
        value blip
   =retrieval>
	isa find-button
   ?visual>
	state free
==>
   =goal>
	state-local blip
   +visual>
	isa move-attention
	screen-pos =visual-location
)

(p click
   =goal>
	isa star-trek-goal
        state-local click
   ?manual>
	preparation free
==>
   +manual>
	isa click-mouse
   =goal>
	state-local verify
   )

(p verify-a-buzzer
   =aural-location>
	isa audio-event
	kind wrong-click-buzzer
   =goal>
	isa star-trek-goal
        state-local verify
        state-global =nn
   =imaginal>
	isa problem-state
        interface =i
   ?manual>
	state free
   ?retrieval>
	state free
==>
   =goal>
	state-local retrieve
   =aural-location>
   )


(p retrieval-error-try-again
   =goal>
	isa star-trek-goal
    =imaginal>
	isa problem-state
        bottom =nn
   ?retrieval>
	state error
==>
   +retrieval>
	isa find-button
        node-name =nn
   =goal>
	state-local find
        )





  ;;;;;;;;;;;;;;;;;;;;;;;;;;  
  ;;; phaser-trained-intervening-subtask
  ;;;;;;;;;;;;;;;;;;;;;;;;;;
  
  #|
(defun phaser1)
|#

(p power-connected1-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name power-connected
        color light-gray
==>
   =goal>
	state-global charge
        state-local retrieve
   =imaginal>
	bottom charge
        middle charge-phaser
   )

(p charge-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name charge
==>
   =goal>
	state-global stop-charging
        state-local retrieve
   =imaginal>
	bottom stop-charging
        middle charge-phaser
   )

(p stop-charging-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name stop-charging
==>
   =goal>
	state-global power-connected2
        state-local retrieve
   =imaginal>
	bottom power-connected2
        middle charge-phaser
   )

(p power-connected2-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name power-connected2
        color blue
==>
   =goal>
	state-global settings
        state-local retrieve
   =imaginal>
	bottom settings
        middle set-focus
   )

(p settings-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name settings
==>
   =goal>
	state-global slider
        state-local retrieve
   =imaginal>
	bottom slider
        middle set-focus
   )

(p slider-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name slider
==>
   =goal>
	state-global focus-set
        state-local retrieve
   =imaginal>
	bottom focus-set
        middle set-focus
   )

(p focus-set-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name focus-set
==>
   =goal>
	state-global firing
        state-local retrieve
   =imaginal>
	bottom firing
        middle fire-phaser
   )

(p firing-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name firing
==>
   =goal>
	state-global tracking
        state-local retrieve
   =imaginal>
	bottom tracking
        middle fire-phaser
   )

(p tracking-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name tracking
==>
   =goal>
	state-global phaser-shoot
        state-local retrieve
   =imaginal>
	bottom phaser-shoot
        middle fire-phaser
   )

(p phaser-shoot-act
   =goal>
   	isa star-trek-goal
        state-local blip
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name phaser-shoot
   ?manual>
	preparation free
==>
   +manual>
	isa punch
        hand left
        finger thumb
   =goal>
        state-local verify
   )

(p phaser-shoot-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name phaser-shoot
==>
   =goal>
	state-global phaser-check-status
        state-local retrieve
   =imaginal>
	bottom phaser-check-status
        middle fire-phaser
   )

(p romulans-not-destroyed
   =goal>
	isa star-trek-goal
        state-local read
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name phaser-check-status
   =visual-location>
	isa visual-location
        kind text
   =visual>
	isa text
   	- value "destroyed"
==>
   =goal>
	state-global power-connected
   	state-local retrieve
   =imaginal>
	middle charge-phaser
        bottom power-connected)

(p romulans-destroyed
   =goal>
	isa star-trek-goal
        state-local read
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name phaser-check-status
   =visual-location>
	isa visual-location
        kind text
   =visual>
	isa text
   	value "destroyed"
==>
   =goal>
	state-global tracking2
        state-local retrieve
   =imaginal>
	middle main-control-phaser
        bottom tracking2)

(p tracking2-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name tracking2
==>
   =goal>
	state-global click-main-control-phaser
	state-local retrieve
   =imaginal>
	middle main-control-phaser
	bottom click-main-control-phaser
   )

(p click-main-control-phaser-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name click-main-control-phaser
==>
   =goal>
	state-global finished-task
        state-local nil
   =imaginal>
	bottom finished-task
   )

(p flagged-step
   =goal>
	isa star-trek-goal
        state-global =nn
        state-local retrieve
        state-micro =nn
   =imaginal>
	isa problem-state
        top do-changed-phaser
   ?retrieval>
	state free
==>
   +retrieval>
	isa change-instruction
        current-flag =nn
   =goal>
        state-local retrieve-change-instruction
        )

(p got-change-instruction
   =goal>
	isa star-trek-goal
        state-local retrieve-change-instruction
   =imaginal>
	isa problem-state
        top do-changed-phaser
   =retrieval>
	isa change-instruction
        current-flag =nn
        do-step =new-nn
        do-subtask =new-st
        next-flag =nf
==>
   =goal>
	state-global =new-nn
        state-local retrieve
        state-micro =nf
   =imaginal>
	middle =new-st
        bottom =new-nn)

(p post-error-retrieve-change-instruction-again
   =aural-location>
	isa audio-event
	kind wrong-click-buzzer
   =goal>
   	isa star-trek-goal
	- state-global =nn
        state-local retrieve
   =imaginal>
	isa problem-state
        top do-changed-phaser
        bottom =nn 
   ?manual>
	state free
   ?retrieval>
   	state free
==>
   +retrieval>
	isa change-instruction
        current-flag =nn
   =goal>
        state-local retrieve-change-instruction
        state-global =nn
        state-micro =nn
 )


	




#|
(defun transporter1)
|#

(p scanner-on-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name scanner-on
==>
   =goal>
	state-global active-scan
        state-local retrieve
   =imaginal>
	bottom active-scan)

(p active-scan-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name active-scan
==>
   =goal>
	state-global lock-signal
        state-local retrieve
   =imaginal>
	bottom lock-signal)

(p lock-signal-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name lock-signal
==>
   =goal>
	state-global scanner-off
        state-local retrieve
   =imaginal>
	bottom scanner-off)

(p transporter-scanner-off-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name scanner-off
==>
   =goal>
	state-global enter-frequency
        state-local retrieve
   =imaginal>
	bottom enter-frequency
        middle frequency)

(p enter-frequency-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name enter-frequency
==>
   =goal>
	state-global type-frequency
        state-local retrieve
   =imaginal>
	bottom type-frequency)

(p type-frequency-act
   =goal>
   	isa star-trek-goal
        state-local read
   =imaginal>
	isa problem-state
   =visual-location>
	isa visual-location
        kind text
   =retrieval>
	isa type
        node-name type-frequency
        key =k
   ?manual>
	preparation free
==>
   +manual>
	isa press-key
	key =k
   =goal>
        state-local type-again)

(p type-frequency-click2
   =goal>
	isa star-trek-goal
        state-local type-again
   =imaginal>
	isa problem-state
   =retrieval>
	isa type
        node-name type-frequency
        key =k
   ?manual>
	preparation free
==>
   +manual>
	isa press-key
	key =k
   =goal>
        state-local verify
    )

(p type-frequency-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name type-frequency
==>
   =goal>
	state-global accept-frequency
        state-local retrieve
   =imaginal>
	bottom accept-frequency)

(p accept-frequency-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name accept-frequency
==>
   =goal>
	state-global transporter-power
        state-local retrieve
   =imaginal>
	middle power
        bottom transporter-power)

(p transporter-power-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name transporter-power
==>
   =goal>
	state-global synchronous-mode
        state-local retrieve
   =imaginal>
	bottom synchronous-mode)

(p synchronous-mode1-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name synchronous-mode
==>
   =goal>
	state-global transporter-shoot
        state-local retrieve
   =imaginal>
	bottom transporter-shoot)

(p transporter-shoot-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name transporter-shoot
==>
   =goal>
	state-global synchronous-mode2
        state-local retrieve
   =imaginal>
	middle main-control-transporter
        bottom synchronous-mode2)

(p synchronous-mode2-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name synchronous-mode2
==>
   =goal>
	state-global transporter-check-status
        state-local retrieve
   =imaginal>
	bottom transporter-check-status)

(p transporter-beam-failed
   =goal>
	isa star-trek-goal
        state-local read
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name transporter-check-status
   =visual-location>
	isa visual-location
        kind text
   =visual>
	isa text
   	- value "successful"
==>
   =goal>
	state-global scanner-on
   	state-local retrieve
   =imaginal>
	middle scan
        bottom scanner-on)

(p beam-successful
   =goal>
	isa star-trek-goal
 	state-global transporter-check-status
        state-local read
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name transporter-check-status
   =visual-location>
	isa visual-location
        kind text
   =visual>
	isa text
   	value "successful"
==>
   =goal>
	state-global click-main-control-transporter
        state-local retrieve
   =imaginal>
	middle main-control-transporter
        bottom click-main-control-transporter)

(p click-main-control-transporter-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name click-main-control-transporter
==>
   =goal>
	state-global finished-task
        state-local nil
   =imaginal>
	bottom finished-task)






;;;;;;;;;;;;;;;;;;;;;;;;;;  
;;; jammer-same
;;;;;;;;;;;;;;;;;;;;;;;;;;

#|
(defun jammer1)
|#

(p jammer-beam-failed
   =goal>
	isa star-trek-goal
 	state-global transporter-check-status
        state-local read
   =imaginal>
	isa problem-state
        top do-jammer
   =retrieval>
	isa find-button
        node-name transporter-check-status
   =visual-location>
	isa visual-location
        kind text
   =visual>
	isa text
   	- value "successful"
==>
   =goal>
	state-global scanner-on
   	state-local retrieve
   =imaginal>
	middle scan
        bottom scanner-on)












   
#|
(defun spp1)
|#
  
(spp 
 (flagged-step :u 5)
 (post-error-retrieve-change-instruction-again :u 11)
 (post-error-retrieve-something-else :u -10)
 )
  
  
  (setf *actr-enabled-p* t)
  
  ;; define-model closing parenthesis
  )






(define-model fdm2
  
  (sgp-fct (list
   ;; model debugging & running
   :v *v* :trace-detail 'low :show-focus nil
   ;; central parameters
   :er t :esc t :ol 4
   ;; procedural
   :crt nil :cst nil
   ;; utility
   :ul t :egs *egs* ;; :iu 20 ;:ut -150 
   ;; visual
   :do-not-harvest 'visual-location 
   :do-not-harvest 'visual 
   :do-not-harvest 'retrieval 
   :do-not-harvest 'imaginal 
   ;; :auto-attend t 
   ;; declarative module
   :mp *mp* :md -10 :ans *ans* :mas *mas* :rt *rt* ;; :blc 2 
   ;; :declarative-num-finsts 20 :declarative-finst-span 30.0 
   ;; :act t 
   ;; buffer-params
   ;; :imaginal-activation 1.0
   ))
  
  (chunk-type star-trek-goal state-micro state-local state-global wm-dummy1 wm-dummy2 wm-dummy3) ;; wmd4)
  (chunk-type schema interface node-name child1 child2 child3 child4)
  (chunk-type find-button interface node-name xcor1 xcor2 ycor1 ycor2 kind value color)
  (chunk-type (type (:include find-button)) key)
  (chunk-type (check-status (:include find-button)))
  (chunk-type wm-dummy value)
  (chunk-type problem-state interface top middle bottom)
  (chunk-type change-instruction current-flag do-step do-subtask next-flag)
  
  (add-dm
   
   (finished-experiment isa star-trek-goal state-global finished-experiment state-local finished-experiment state-micro finished-experiment)
   
   
   (phaser-goal isa star-trek-goal state-global power-connected state-local retrieve state-micro nothing wm-dummy1 wm-dummy-chunk1 wm-dummy2 wm-dummy-chunk2 wm-dummy3 wm-dummy-chunk3) ;; wmd4 wmd-chunk4)
   (phaser-imaginal isa problem-state interface phaser top do-phaser middle charge-phaser bottom power-connected)
   (do-phaser isa schema interface phaser node-name do-phaser child1 charge-phaser child2 set-focus child3 firing child4 main-control-phaser)
   	(charge-phaser isa schema interface phaser node-name charge-phaser child1 power-connected child2 charge child3 stop-charging child4 power-connected2)
   		(power-connected isa find-button interface phaser node-name power-connected  xcor1 690 xcor2 730 ycor1 190 ycor2 220 kind visual-object value box color light-gray)
   		(charge isa find-button interface phaser node-name charge  xcor1 720 xcor2 760 ycor1 130 ycor2 160 kind oval value oval color light-gray)
   		(stop-charging isa find-button interface phaser node-name stop-charging  xcor1 720 xcor2 760 ycor1 260 ycor2 300 kind oval value oval color light-gray)
   		(power-connected2 isa find-button interface phaser node-name power-connected2  xcor1 690 xcor2 730 ycor1 190 ycor2 220 kind visual-object value box color blue)
   	(set-focus isa schema interface phaser node-name set-focus child1 focus child2 slider child3 focus-set child4 NOTHING)
   		(settings isa find-button interface phaser node-name settings  xcor1 470 xcor2 490 ycor1 590 ycor2 610 kind oval value oval color light-gray)
   		(slider isa find-button interface phaser node-name slider  xcor1 570 xcor2 620 ycor1 620 ycor2 680 kind visual-object value box color black)
   		(focus-set isa find-button interface phaser node-name focus-set  xcor1 580 xcor2 640 ycor1 570 ycor2 630 kind visual-object value box color light-gray)
   	(fire-phaser isa schema interface phaser node-name fire-phaser child1 firing child2 tracking child3 phaser-shoot child4 phasercheck-status)
  		(firing isa find-button interface phaser node-name firing  xcor1 120 xcor2 180 ycor1 380 ycor2 440 kind oval value oval color light-gray)
   		(tracking isa find-button interface phaser node-name tracking  xcor1 300 xcor2 360 ycor1 380 ycor2 440 kind oval value oval color light-gray)
                (phaser-shoot isa type interface phaser node-name phaser-shoot  xcor1 230 xcor2 290 ycor1 200 ycor2 260 kind visual-object value blip color black key space)
   		(phaser-check-status isa check-status interface phaser node-name phaser-check-status  xcor1 135 xcor2 175 ycor1 630 ycor2 670 kind text value text color black)
   	(main-control-phaser isa schema interface phaser node-name main-control-phaser child1 tracking2 child2 click-main-control-phaser child3 NOTHING child4 NOTHING)
   		(tracking2 isa find-button interface phaser node-name tracking2  xcor1 300 xcor2 360 ycor1 380 ycor2 440 kind oval value oval color light-gray)
   		(click-main-control-phaser isa find-button interface phaser node-name click-main-control-phaser  xcor1 780 xcor2 910 ycor1 570 ycor2 640 kind oval value oval color light-gray)

   
   (transporter-goal isa star-trek-goal state-global scanner-on state-local retrieve state-micro nothing wm-dummy1 wm-dummy-chunk1 wm-dummy2 wm-dummy-chunk2 wm-dummy3 wm-dummy-chunk3)
   (transporter-imaginal isa problem-state interface transporter top do-transporter middle scan bottom scanner-on)
   (do-transporter isa schema interface transporter node-name do-transporter child1 scan child2 frequency child3 power child4 main-control-transporter)
   	(scan isa schema interface transporter node-name scan child1 scanner-on child2 active-scan child3 lock-signal child4 scanner-off)
   		(scanner-on isa find-button interface transporter node-name scanner-on  xcor1 690 xcor2 730 ycor1 260 ycor2 280 kind oval value oval color light-gray)
   		(active-scan isa find-button interface transporter node-name active-scan  xcor1 690 xcor2 730 ycor1 300 ycor2 320 kind oval value oval color light-gray)
		(lock-signal isa find-button interface transporter node-name lock-signal  xcor1 690 xcor2 730 ycor1 320 ycor2 340 kind oval value oval color light-gray)
   		(scanner-off isa find-button interface transporter node-name scanner-off  xcor1 690 xcor2 730 ycor1 280 ycor2 300 kind oval value oval color light-gray)
   	(frequency isa schema interface transporter node-name frequency child1 enter-frequency child2 type child3 accept-frequency child4 nothing)
   		(enter-frequency isa find-button interface transporter node-name enter-frequency  xcor1 500 xcor2 530 ycor1 145 ycor2 175 kind oval value oval color light-gray)
   		(type-frequency isa type interface transporter node-name type-frequency  xcor1 460 xcor2 490 ycor1 185 ycor2 215 kind text value nothing color black key 5)
                (accept-frequency isa find-button interface transporter node-name accept-frequency  xcor1 435 xcor2 465 ycor1 215 ycor2 245 kind visual-object value box color light-gray)
        (power isa schema interface transporter node-name power child1 transporter-power child2 synchronous-mode child3 transporter-shoot child4 nothing)
        	(transporter-power isa find-button interface transporter node-name transporter-power  xcor1 185 xcor2 215 ycor1 215 ycor2 245 kind visual-object value box color light-gray)
                (synchronous-mode isa find-button interface transporter node-name synchronous-mode  xcor1 245 xcor2 275 ycor1 145 ycor2 175 kind oval value oval color light-gray)
                (transporter-shoot isa find-button interface transporter node-name transporter-shoot  xcor1 120 xcor2 450 ycor1 350 ycor2 700 kind visual-object value unknown color black)
        (main-control-transporter isa schema interface transporter node-name main-control-transporter child1 synchronous-mode2 child2 transporter-check-status child3 click-main-control-transporter child4 nothing)
                (synchronous-mode2 isa find-button interface transporter node-name synchronous-mode2 xcor1 245 xcor2 275 ycor1 145 ycor2 175 kind oval value oval color light-gray)
   		(transporter-check-status isa find-button interface transporter node-name transporter-check-status  xcor1 530 xcor2 800 ycor1 460 ycor2 500 kind text value nothing color black)
        	(click-main-control-transporter isa find-button interface transporter node-name click-main-control-transporter  xcor1 545 xcor2 575 ycor1 580 ycor2 610 kind oval value oval color light-gray)
    


  ;;; (frequency, scanner, power, shoot)
   (jammer-goal isa star-trek-goal state-global scanner-on state-local retrieve state-micro nothing wm-dummy1 wm-dummy-chunk1 wm-dummy2 wm-dummy-chunk2 wm-dummy3 wm-dummy-chunk3)
   (jammer-imaginal isa problem-state interface transporter top do-jammer middle scan bottom scanner-on)
   (do-jammer isa schema interface transporter node-name do-jammer child1 frequency child2 scan child3 power child4 main-control-transporter)



   (wm-dummy-chunk1 isa wm-dummy value "a")
   (wm-dummy-chunk2 isa wm-dummy value "b")
   (wm-dummy-chunk3 isa wm-dummy value "c")
   (nothing isa wm-dummy value "nothing")
   
   )

  (sdp-fct '((power-connected2 :base-level -1.2) (tracking2 :base-level -1.1) (scanner-on :base-level -0.4) (scanner-off :base-level -0.4) (synchronous-mode2 :base-level -0.4)))

   (set-similarities
    (phaser-goal do-phaser -0.95) (phaser-goal charge-phaser -0.95) (phaser-goal set-focus -0.95) (phaser-goal fire-phaser -0.95) (phaser-goal main-control-phaser -0.95)
    (do-phaser charge-phaser -0.95) (do-phaser set-focus -0.95) (do-phaser fire-phaser -0.95) (do-phaser main-control-phaser -0.95)
   	(charge-phaser power-connected -0.95) (charge-phaser charge -0.95) (charge-phaser stop-charging -0.95) (charge-phaser power-connected2 -0.95)
      (set-focus settings -0.95) (set-focus slider -0.95) (set-focus focus-set -0.95)
      (fire-phaser firing -0.95) (fire-phaser tracking -0.95) (fire-phaser phaser-shoot -0.95) (fire-phaser phaser-check-status -0.95)
      (main-control-phaser click-main-control-phaser -0.95)
      (power-connected charge -0.95) (power-connected stop-charging -0.95) (power-connected power-connected2 -0.95)
      (charge stop-charging -0.95) (charge power-connected2 -0.95)
      (stop-charging power-connected2 -0.95)
      (settings slider -0.95) (settings focus-set -0.95) (slider focus-set -0.95)
      (firing tracking -0.95) (firing phaser-shoot -0.95) (firing phaser-check-status -0.95)
      (tracking phaser-shoot -0.95) (tracking phaser-check-status -0.95)
      (phaser-shoot phaser-check-status -0.95)
      (tracking2 click-main-control-phaser -0.7)

      (do-phaser power-connected -1) (do-phaser charge -1) (do-phaser stop-charging -1) (do-phaser power-connected2 -1) (do-phaser settings -1) (do-phaser slider -1) (do-phaser focus-set -1) (do-phaser firing -1) (do-phaser tracking -1) (do-phaser phaser-shoot -1) (do-phaser phaser-check-status -1) (do-phaser tracking2 -1) (do-phaser click-main-control-phaser -1)
      (charge-phaser set-focus -1) (charge-phaser fire-phaser -1) (charge-phaser main-control-phaser -1) (set-focus fire-phaser -1) (set-focus main-control-phaser -1) (fire-phaser main-control-phaser -1)
      (charge-phaser settings -1) (charge-phaser slider -1) (charge-phaser focus-set -1) (charge-phaser firing -1) (charge-phaser tracking -1) (charge-phaser phaser-shoot -1) (charge-phaser phaser-check-status -1) (charge-phaser tracking2 -1) (charge-phaser click-main-control-phaser -1)
      	(power-connected settings -1) (power-connected slider -1) (power-connected focus-set -1) (power-connected firing -1) (power-connected tracking -1) (power-connected phaser-shoot -1) (power-connected phaser-check-status -1) (power-connected tracking2 -1) (power-connected click-main-control-phaser -1)
      	(charge settings -1) (charge slider -1) (charge focus-set -1) (charge firing -1) (charge tracking -1) (charge phaser-shoot -1) (charge phaser-check-status -1) (charge tracking2 -1) (charge click-main-control-phaser -1)
      	(stop-charging settings -1) (stop-charging slider -1) (stop-charging focus-set -1) (stop-charging firing -1) (stop-charging tracking -1) (stop-charging phaser-shoot -1) (stop-charging phaser-check-status -1) (stop-charging tracking2 -1) (stop-charging click-main-control-phaser -1)
      	(power-connected2 settings -0.7) (power-connected2 slider -1) (power-connected2 focus-set -1) (power-connected2 firing -1) (power-connected2 tracking -1) (power-connected2 phaser-shoot -1) (power-connected2 phaser-check-status -1) (power-connected2 tracking2 -1) (power-connected2 click-main-control-phaser -1)
      (set-focus power-connected -1) (set-focus charge -1) (set-focus stop-charging -1) (set-focus power-connected2 -1) (set-focus firing -1) (set-focus tracking -1) (set-focus phaser-shoot -1) (set-focus phaser-check-status -1) (set-focus tracking2 -1) (set-focus click-main-control-phaser -1)
      	(settings firing -1) (settings tracking -1) (settings phaser-shoot -1) (settings phaser-check-status -1) (settings tracking2 -1) (settings click-main-control-phaser -1)
      	(slider firing -1) (slider tracking -1) (slider phaser-shoot -1) (slider phaser-check-status -1) (slider tracking2 -1) (slider click-main-control-phaser -1)
      	(focus-set firing -1) (focus-set tracking -1) (focus-set phaser-shoot -1) (focus-set phaser-check-status -1) (focus-set tracking2 -1) (focus-set click-main-control-phaser -1)
      (fire-phaser power-connected -1) (fire-phaser charge -1) (fire-phaser stop-charging -1) (fire-phaser power-connected2 -1) (fire-phaser settings -1) (fire-phaser slider -1) (fire-phaser focus-set -1) (fire-phaser click-main-control-phaser -1)
      	(firing click-main-control-phaser -1)
      	(tracking click-main-control-phaser -1)
      	(phaser-shoot click-main-control-phaser -1)
      	(phaser-check-status click-main-control-phaser -1)
      (main-control-phaser power-connected -1) (main-control-phaser charge -1) (main-control-phaser stop-charging -1) (main-control-phaser power-connected2 -1) (main-control-phaser settings -1) (main-control-phaser slider -1) (main-control-phaser focus-set -1) (main-control-phaser firing -1) (main-control-phaser tracking -1) (main-control-phaser phaser-shoot -1) (main-control-phaser tracking2 -1) (main-control-phaser phaser-check-status -1)
      

   (transporter-goal do-transporter -0.95) (transporter-goal scan -0.95) (transporter-goal frequency -0.95) (transporter-goal power -0.95) (transporter-goal main-control-transporter -0.95)
   (jammer-goal do-jammer -0.95) (jammer-goal scan -0.95) (jammer-goal frequency -0.95) (jammer-goal power -0.95) (jammer-goal main-control-transporter -0.95)
   (do-transporter scan -0.95) (do-transporter frequency -0.95) (do-transporter power -0.95) (do-transporter main-control-transporter -0.95)
   (do-jammer scan -0.95) (do-jammer frequency -0.95) (do-jammer power -0.95) (do-jammer main-control-transporter -0.95)
   	(scan scanner-on -0.95) (scan active-scan -0.95) (scan lock-signal -0.95) (scan scanner-off -0.95) 
        (scanner-on active-scan -0.75) (scanner-on lock-signal -0.85) (scanner-on scanner-off -0.85) (active-scan lock-signal -0.9) (active-scan scanner-off -0.9) (lock-signal scanner-off -0.72)
      (frequency enter-frequency -0.95) (frequency type-frequency -0.95) (frequency accept-frequency -0.95) (enter-frequency type-frequency -0.95) (enter-frequency accept-frequency -0.95) (type-frequency accept-frequency -0.95)
      (power transporter-power -0.95) (power synchronous-mode -0.95) (power transporter-shoot -0.95)  (power transporter-check-status -0.95) (transporter-power synchronous-mode -0.95) (transporter-power transporter-shoot -0.95) (synchronous-mode transporter-shoot -0.95)  
      (main-control-transporter synchronous-mode2 -0.95) (main-control-transporter transporter-check-status -0.95) (main-control-transporter click-main-control-transporter -0.95)
      (synchronous-mode2 transporter-check-status -0.95) (synchronous-mode2 click-main-control-transporter -0.9) (transporter-check-status click-main-control-transporter -0.95)

      (do-transporter scanner-on -1) (do-transporter active-scan -1) (do-transporter lock-signal -1) (do-transporter scanner-off -1) (do-transporter enter-frequency -1) (do-transporter type-frequency -1) (do-transporter accept-frequency -1) (do-transporter transporter-power -1) (do-transporter synchronous-mode -1) (do-transporter transporter-shoot -1) (do-transporter synchronous-mode2 -1) (do-transporter transporter-check-status -1) (do-transporter click-main-control-transporter -1)
      (do-jammer scanner-on -1) (do-jammer active-scan -1) (do-jammer lock-signal -1) (do-jammer scanner-off -1) (do-jammer enter-frequency -1) (do-jammer type-frequency -1) (do-jammer accept-frequency -1) (do-jammer transporter-power -1) (do-jammer synchronous-mode -1) (do-jammer transporter-shoot -1) (do-jammer synchronous-mode2 -1) (do-jammer transporter-check-status -1) (do-jammer click-main-control-transporter -1)
      (scan enter-frequency -1) (scan type-frequency -1) (scan accept-frequency -1) (scan transporter-power -1) (scan synchronous-mode -1) (scan transporter-shoot -1) (scan synchronous-mode2 -1) (scan transporter-check-status -1) (scan click-main-control-transporter -1)
      (scanner-on enter-frequency -0.9) (scanner-on type-frequency -1) (scanner-on accept-frequency -1) (scanner-on transporter-power -1) (scanner-on synchronous-mode -1) (scanner-on transporter-shoot -1) (scanner-on synchronous-mode2 -1) (scanner-on transporter-check-status -1) (scanner-on click-main-control-transporter -1)
      (active-scan enter-frequency -0.9) (active-scan type-frequency -1) (active-scan accept-frequency -1) (active-scan transporter-power -1) (active-scan synchronous-mode -1) (active-scan transporter-shoot -1) (active-scan synchronous-mode2 -1) (active-scan transporter-check-status -1) (active-scan click-main-control-transporter -1)
      (lock-signal enter-frequency -0.9) (lock-signal type-frequency -1) (lock-signal accept-frequency -1) (lock-signal transporter-power -1) (lock-signal synchronous-mode -1) (lock-signal transporter-shoot -1) (lock-signal synchronous-mode2 -1) (lock-signal transporter-check-status -1) (lock-signal click-main-control-transporter -1)
      (scanner-off enter-frequency -0.7) (scanner-off type-frequency -1) (scanner-off accept-frequency -1) (scanner-off transporter-power -1) (scanner-off synchronous-mode -1) (scanner-off transporter-shoot -1) (scanner-off synchronous-mode2 -1) (scanner-off transporter-check-status -1) (scanner-off click-main-control-transporter -1)
      (frequency transporter-power -1) (frequency synchronous-mode -1) (frequency transporter-shoot -1) (frequency synchronous-mode2 -1) (frequency transporter-check-status -1) (frequency click-main-control-transporter -1)
      (enter-frequency transporter-power -1) (enter-frequency synchronous-mode -1) (enter-frequency transporter-shoot -1) (enter-frequency synchronous-mode2 -1) (enter-frequency transporter-check-status -1) (enter-frequency click-main-control-transporter -1)
      (type-frequency transporter-power -1) (type-frequency synchronous-mode -1) (type-frequency transporter-shoot -1) (type-frequency synchronous-mode2 -1) (type-frequency transporter-check-status -1) (type-frequency click-main-control-transporter -1)
      (accept-frequency transporter-power -1) (accept-frequency synchronous-mode -1) (accept-frequency transporter-shoot -1) (accept-frequency synchronous-mode2 -1) (accept-frequency transporter-check-status -1) (accept-frequency click-main-control-transporter -1)
      (power synchronous-mode2 -1) (power transporter-check-status -1) (power click-main-control-transporter -1)
      (transporter-power synchronous-mode2 -1) (transporter-power transporter-check-status -1) (transporter-power click-main-control-transporter -1)
      (synchronous-mode synchronous-mode2 -1) (synchronous-mode transporter-check-status -1) (synchronous-mode click-main-control-transporter -1)
      (transporter-shoot synchronous-mode2 -1) (transporter-shoot transporter-check-status -1) (transporter-shoot click-main-control-transporter -1)
      (transporter-shoot click-main-control-transporter -1)
      (transporter-check-status click-main-control-transporter -1)
      )


  (start-hand-at-mouse)
  
  
  
  
  
#|
(defun generic-rfm-productions2 ())
|#


(p retrieve
   ?aural-location>
	buffer empty
   =goal>
   	isa star-trek-goal
	state-global =nn
        state-local retrieve
        - state-micro =nn 
        state-micro =sm
   ?manual>
	state free
   ?retrieval>
   	state free
==>
   +retrieval>
   	isa find-button 
   	node-name =nn
        - node-name =sm
   =goal>
   	state-local find
)

(p post-error-retrieve-the-same
   =aural-location>
	isa audio-event
	kind wrong-click-buzzer
   =goal>
   	isa star-trek-goal
	state-global =nn
        state-local retrieve
        - state-micro =nn 
        state-micro =sm
   ?manual>
	state free
   ?retrieval>
   	state free
==>
   +retrieval>
   	isa find-button 
   	node-name =nn
        - node-name =sm
   =goal>
   	state-local find
 )

(p post-error-retrieve-something-else
   =aural-location>
	isa audio-event
	kind wrong-click-buzzer
   =goal>
   	isa star-trek-goal
	state-global =nn
        state-local retrieve
        - state-micro =nn 
        state-micro =sm
   =imaginal>
	isa problem-state
        interface =i
   ?retrieval>
	state free
==>
   =goal>
	state-local find
   +retrieval>
   	isa find-button 
        interface =i
   	- node-name =nn
)

(p find
   =goal>
   	isa star-trek-goal
        state-local find
   =retrieval>
   	isa find-button
        node-name =nn
        xcor1       =x1
        xcor2       =x2
        ycor1       =y1
        ycor2       =y2
        kind =k
        color =c
==>
   +visual-location>
      ISA         visual-location
      screen-x    (within =x1 =x2)
      screen-y    (within =y1 =y2)
      kind =k
      color =c
   =goal>
   	state-local move
)

(p move-mouse-cursor
   =goal>
	isa star-trek-goal
        state-local move
   =visual-location>
	isa visual-location
        - kind text
        - value blip
   =retrieval>
	isa find-button
   ?manual>
	preparation free
==>
   =goal>
	state-local click
   +manual>
	isa move-cursor
        loc =visual-location
)

(p find-visual-location-failure-retrieve-the-same
   =goal>
	isa star-trek-goal
        state-global =nn
        state-local move
        state-micro =sm
   ?visual-location>
	state error
==>
   +retrieval>
   	isa find-button 
   	node-name =nn
        - node-name =sm
   =goal>
   	state-local find
 )

(p find-visual-location-failure-retrieve-something-else
   =goal>
	isa star-trek-goal
        state-global =nn
        state-local move
   =imaginal>
	isa problem-state
        interface =i
   ?visual-location>
	state error
==>
   =goal>
	state-local find
   +retrieval>
   	isa find-button 
        interface =i
   	- node-name =nn
)	

(p move-visual-attention-text
   =goal>
	isa star-trek-goal
        state-local move
   =visual-location>
	isa visual-location
        kind text
   =retrieval>
	isa find-button
   ?visual>
	state free
==>
   =goal>
	state-local read
   +visual>
	isa move-attention
	screen-pos =visual-location
)

(p move-visual-attention-blip
   =goal>
	isa star-trek-goal
        state-local move
   =visual-location>
	isa visual-location
        kind visual-object
        value blip
   =retrieval>
	isa find-button
   ?visual>
	state free
==>
   =goal>
	state-local blip
   +visual>
	isa move-attention
	screen-pos =visual-location
)

(p click
   =goal>
	isa star-trek-goal
        state-local click
   ?manual>
	preparation free
==>
   +manual>
	isa click-mouse
   =goal>
	state-local verify
   )

(p verify-a-buzzer
   =aural-location>
	isa audio-event
	kind wrong-click-buzzer
   =goal>
	isa star-trek-goal
        state-local verify
        state-global =nn
   =imaginal>
	isa problem-state
        interface =i
   ?manual>
	state free
   ?retrieval>
	state free
==>
   =goal>
	state-local retrieve
   =aural-location>
   )


(p retrieval-error-try-again
   =goal>
	isa star-trek-goal
    =imaginal>
	isa problem-state
        bottom =nn
   ?retrieval>
	state error
==>
   +retrieval>
	isa find-button
        node-name =nn
   =goal>
	state-local find
        )






  ;;;;;;;;;;;;;;;;;;;;;;;;;;  
  ;;; phaser-no-intervening-subtask
  ;;;;;;;;;;;;;;;;;;;;;;;;;;
  
  #|
(defun phaser2)
|#

(p power-connected1-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name power-connected
        color light-gray
==>
   =goal>
	state-global charge
        state-local retrieve
   =imaginal>
	bottom charge
        middle charge-phaser
   )

(p charge-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name charge
==>
   =goal>
	state-global stop-charging
        state-local retrieve
   =imaginal>
	bottom stop-charging
        middle charge-phaser
   )

(p stop-charging-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name stop-charging
==>
   =goal>
	state-global power-connected2
        state-local retrieve
   =imaginal>
	bottom power-connected2
        middle charge-phaser
   )

(p power-connected2-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name power-connected2
        color blue
==>
   =goal>
	state-global settings
        state-local retrieve
   =imaginal>
	bottom settings
        middle set-focus
   )

(p settings-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name settings
==>
   =goal>
	state-global slider
        state-local retrieve
   =imaginal>
	bottom slider
        middle set-focus
   )

(p slider-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name slider
==>
   =goal>
	state-global focus-set
        state-local retrieve
   =imaginal>
	bottom focus-set
        middle set-focus
   )

(p focus-set-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name focus-set
==>
   =goal>
	state-global firing
        state-local retrieve
   =imaginal>
	bottom firing
        middle fire-phaser
   )

(p firing-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name firing
==>
   =goal>
	state-global tracking
        state-local retrieve
   =imaginal>
	bottom tracking
        middle fire-phaser
   )

(p tracking-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name tracking
==>
   =goal>
	state-global phaser-shoot
        state-local retrieve
   =imaginal>
	bottom phaser-shoot
        middle fire-phaser
   )

(p phaser-shoot-act
   =goal>
   	isa star-trek-goal
        state-local blip
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name phaser-shoot
   ?manual>
	preparation free
==>
   +manual>
	isa punch
        hand left
        finger thumb
   =goal>
        state-local verify
   )

(p phaser-shoot-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name phaser-shoot
==>
   =goal>
	state-global phaser-check-status
        state-local retrieve
   =imaginal>
	bottom phaser-check-status
        middle fire-phaser
   )

(p romulans-not-destroyed
   =goal>
	isa star-trek-goal
        state-local read
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name phaser-check-status
   =visual-location>
	isa visual-location
        kind text
   =visual>
	isa text
   	- value "destroyed"
==>
   =goal>
	state-global power-connected
   	state-local retrieve
   =imaginal>
	middle charge-phaser
        bottom power-connected)

(p romulans-destroyed
   =goal>
	isa star-trek-goal
        state-local read
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name phaser-check-status
   =visual-location>
	isa visual-location
        kind text
   =visual>
	isa text
   	value "destroyed"
==>
   =goal>
	state-global tracking2
        state-local retrieve
   =imaginal>
	middle main-control-phaser
        bottom tracking2)

(p tracking2-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name tracking2
==>
   =goal>
	state-global click-main-control-phaser
	state-local retrieve
   =imaginal>
	middle main-control-phaser
	bottom click-main-control-phaser
   )

(p click-main-control-phaser-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name click-main-control-phaser
==>
   =goal>
	state-global finished-task
        state-local nil
   =imaginal>
	bottom finished-task
   )

	




#|
(defun transporter2)
|#

(p scanner-on-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name scanner-on
==>
   =goal>
	state-global active-scan
        state-local retrieve
   =imaginal>
	bottom active-scan)

(p active-scan-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name active-scan
==>
   =goal>
	state-global lock-signal
        state-local retrieve
   =imaginal>
	bottom lock-signal)

(p lock-signal-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name lock-signal
==>
   =goal>
	state-global scanner-off
        state-local retrieve
   =imaginal>
	bottom scanner-off)

(p transporter-scanner-off-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name scanner-off
==>
   =goal>
	state-global enter-frequency
        state-local retrieve
   =imaginal>
	bottom enter-frequency
        middle frequency)

(p enter-frequency-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name enter-frequency
==>
   =goal>
	state-global type-frequency
        state-local retrieve
   =imaginal>
	bottom type-frequency)

(p type-frequency-act
   =goal>
   	isa star-trek-goal
        state-local read
   =imaginal>
	isa problem-state
   =visual-location>
	isa visual-location
        kind text
   =retrieval>
	isa type
        node-name type-frequency
        key =k
   ?manual>
	preparation free
==>
   +manual>
	isa press-key
	key =k
   =goal>
        state-local type-again)

(p type-frequency-click2
   =goal>
	isa star-trek-goal
        state-local type-again
   =imaginal>
	isa problem-state
   =retrieval>
	isa type
        node-name type-frequency
        key =k
   ?manual>
	preparation free
==>
   +manual>
	isa press-key
	key =k
   =goal>
        state-local verify
    )

(p type-frequency-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name type-frequency
==>
   =goal>
	state-global accept-frequency
        state-local retrieve
   =imaginal>
	bottom accept-frequency)

(p accept-frequency-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name accept-frequency
==>
   =goal>
	state-global transporter-power
        state-local retrieve
   =imaginal>
	middle power
        bottom transporter-power)

(p transporter-power-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name transporter-power
==>
   =goal>
	state-global synchronous-mode
        state-local retrieve
   =imaginal>
	bottom synchronous-mode)

(p synchronous-mode1-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name synchronous-mode
==>
   =goal>
	state-global transporter-shoot
        state-local retrieve
   =imaginal>
	bottom transporter-shoot)

(p transporter-shoot-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name transporter-shoot
==>
   =goal>
	state-global synchronous-mode2
        state-local retrieve
   =imaginal>
	middle main-control-transporter
        bottom synchronous-mode2)

(p synchronous-mode2-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name synchronous-mode2
==>
   =goal>
	state-global transporter-check-status
        state-local retrieve
   =imaginal>
	bottom transporter-check-status)

(p transporter-beam-failed
   =goal>
	isa star-trek-goal
        state-local read
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name transporter-check-status
   =visual-location>
	isa visual-location
        kind text
   =visual>
	isa text
   	- value "successful"
==>
   =goal>
	state-global scanner-on
   	state-local retrieve
   =imaginal>
	middle scan
        bottom scanner-on)

(p beam-successful
   =goal>
	isa star-trek-goal
 	state-global transporter-check-status
        state-local read
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name transporter-check-status
   =visual-location>
	isa visual-location
        kind text
   =visual>
	isa text
   	value "successful"
==>
   =goal>
	state-global click-main-control-transporter
        state-local retrieve
   =imaginal>
	middle main-control-transporter
        bottom click-main-control-transporter)

(p click-main-control-transporter-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name click-main-control-transporter
==>
   =goal>
	state-global finished-task
        state-local nil
   =imaginal>
	bottom finished-task)






;;;;;;;;;;;;;;;;;;;;;;;;;;  
;;; jammer-untrained-scanner-step-reordering
;;; active-scan, scanner-off, lock-signal, scanner-on
;;;;;;;;;;;;;;;;;;;;;;;;;;

#|
(defun jammer2)
|#

(p flagged-step-jammer
   =goal>
	isa star-trek-goal
        state-global =nn
        state-local retrieve
        state-micro =nn
   =imaginal>
	isa problem-state
        top do-changed-jammer
   ?retrieval>
	state free
==>
   +retrieval>
	isa change-instruction
        current-flag =nn
   =goal>
        state-local retrieve-change-instruction
        )

(p got-change-instruction-jammer
   =goal>
	isa star-trek-goal
        state-local retrieve-change-instruction
   =imaginal>
	isa problem-state
        top do-changed-jammer
   =retrieval>
	isa change-instruction
        current-flag =nn
        do-step =new-nn
        do-subtask =new-st
        next-flag =nf
==>
   =goal>
	state-global =new-nn
        state-local retrieve
        state-micro =nf
        )

(p post-error-retrieve-change-instruction-again
   =aural-location>
	isa audio-event
	kind wrong-click-buzzer
   =goal>
   	isa star-trek-goal
	- state-global =nn
        state-local retrieve
   =imaginal>
	isa problem-state
        top do-changed-jammer
        bottom =nn 
   ?manual>
	state free
   ?retrieval>
   	state free
==>
   +retrieval>
	isa change-instruction
        current-flag =nn
   =goal>
        state-local retrieve-change-instruction
        state-global =nn
        state-micro =nn
 )
















   
#|
(defun spp2)
|#
  
(spp 
 (flagged-step-jammer :u 5)
 (post-error-retrieve-change-instruction-again :u 11)
 (post-error-retrieve-something-else :u -10)
 )
  
  
  (setf *actr-enabled-p* t)
  
  ;; define-model closing parenthesis
  )





(define-model fdm3
  
  (sgp-fct (list
   ;; model debugging & running
   :v *v* :trace-detail 'low :show-focus nil
   ;; central parameters
   :er t :esc t :ol 4
   ;; procedural
   :crt nil :cst nil
   ;; utility
   :ul t :egs *egs* ;; :iu 20 ;:ut -150 
   ;; visual
   :do-not-harvest 'visual-location 
   :do-not-harvest 'visual 
   :do-not-harvest 'retrieval 
   :do-not-harvest 'imaginal 
   ;; :auto-attend t 
   ;; declarative module
   :mp *mp* :md -10 :ans *ans* :mas *mas* :rt *rt* ;; :blc 2 
   ;; :declarative-num-finsts 20 :declarative-finst-span 30.0 
   ;; :act t 
   ;; buffer-params
   ;; :imaginal-activation 1.0
   ))
  
  (chunk-type star-trek-goal state-micro state-local state-global wm-dummy1 wm-dummy2 wm-dummy3) ;; wmd4)
  (chunk-type schema interface node-name child1 child2 child3 child4)
  (chunk-type find-button interface node-name xcor1 xcor2 ycor1 ycor2 kind value color)
  (chunk-type (type (:include find-button)) key)
  (chunk-type (check-status (:include find-button)))
  (chunk-type wm-dummy value)
  (chunk-type problem-state interface top middle bottom)
  
  (add-dm
   
   (finished-experiment isa star-trek-goal state-global finished-experiment state-local finished-experiment state-micro finished-experiment)
   
   
   (phaser-goal isa star-trek-goal state-global power-connected state-local retrieve state-micro nothing wm-dummy1 wm-dummy-chunk1 wm-dummy2 wm-dummy-chunk2 wm-dummy3 wm-dummy-chunk3) ;; wmd4 wmd-chunk4)
   (phaser-imaginal isa problem-state interface phaser top do-phaser middle charge-phaser bottom power-connected)
   (do-phaser isa schema interface phaser node-name do-phaser child1 charge-phaser child2 set-focus child3 firing child4 main-control-phaser)
   	(charge-phaser isa schema interface phaser node-name charge-phaser child1 power-connected child2 charge child3 stop-charging child4 power-connected2)
   		(power-connected isa find-button interface phaser node-name power-connected  xcor1 690 xcor2 730 ycor1 190 ycor2 220 kind visual-object value box color light-gray)
   		(charge isa find-button interface phaser node-name charge  xcor1 720 xcor2 760 ycor1 130 ycor2 160 kind oval value oval color light-gray)
   		(stop-charging isa find-button interface phaser node-name stop-charging  xcor1 720 xcor2 760 ycor1 260 ycor2 300 kind oval value oval color light-gray)
   		(power-connected2 isa find-button interface phaser node-name power-connected2  xcor1 690 xcor2 730 ycor1 190 ycor2 220 kind visual-object value box color blue)
   	(set-focus isa schema interface phaser node-name set-focus child1 focus child2 slider child3 focus-set child4 NOTHING)
   		(settings isa find-button interface phaser node-name settings  xcor1 470 xcor2 490 ycor1 590 ycor2 610 kind oval value oval color light-gray)
   		(slider isa find-button interface phaser node-name slider  xcor1 570 xcor2 620 ycor1 620 ycor2 680 kind visual-object value box color black)
   		(focus-set isa find-button interface phaser node-name focus-set  xcor1 580 xcor2 640 ycor1 570 ycor2 630 kind visual-object value box color light-gray)
   	(fire-phaser isa schema interface phaser node-name fire-phaser child1 firing child2 tracking child3 phaser-shoot child4 phasercheck-status)
  		(firing isa find-button interface phaser node-name firing  xcor1 120 xcor2 180 ycor1 380 ycor2 440 kind oval value oval color light-gray)
   		(tracking isa find-button interface phaser node-name tracking  xcor1 300 xcor2 360 ycor1 380 ycor2 440 kind oval value oval color light-gray)
                (phaser-shoot isa type interface phaser node-name phaser-shoot  xcor1 230 xcor2 290 ycor1 200 ycor2 260 kind visual-object value blip color black key space)
   		(phaser-check-status isa check-status interface phaser node-name phaser-check-status  xcor1 135 xcor2 175 ycor1 630 ycor2 670 kind text value text color black)
   	(main-control-phaser isa schema interface phaser node-name main-control-phaser child1 tracking2 child2 click-main-control-phaser child3 NOTHING child4 NOTHING)
   		(tracking2 isa find-button interface phaser node-name tracking2  xcor1 300 xcor2 360 ycor1 380 ycor2 440 kind oval value oval color light-gray)
   		(click-main-control-phaser isa find-button interface phaser node-name click-main-control-phaser  xcor1 780 xcor2 910 ycor1 570 ycor2 640 kind oval value oval color light-gray)

   
   (transporter-goal isa star-trek-goal state-global scanner-on state-local retrieve state-micro nothing wm-dummy1 wm-dummy-chunk1 wm-dummy2 wm-dummy-chunk2 wm-dummy3 wm-dummy-chunk3)
   (transporter-imaginal isa problem-state interface transporter top do-transporter middle scan bottom scanner-on)
   (do-transporter isa schema interface transporter node-name do-transporter child1 scan child2 frequency child3 power child4 main-control-transporter)
   	(scan isa schema interface transporter node-name scan child1 scanner-on child2 active-scan child3 lock-signal child4 scanner-off)
   		(scanner-on isa find-button interface transporter node-name scanner-on  xcor1 690 xcor2 730 ycor1 260 ycor2 280 kind oval value oval color light-gray)
   		(active-scan isa find-button interface transporter node-name active-scan  xcor1 690 xcor2 730 ycor1 300 ycor2 320 kind oval value oval color light-gray)
		(lock-signal isa find-button interface transporter node-name lock-signal  xcor1 690 xcor2 730 ycor1 320 ycor2 340 kind oval value oval color light-gray)
   		(scanner-off isa find-button interface transporter node-name scanner-off  xcor1 690 xcor2 730 ycor1 280 ycor2 300 kind oval value oval color light-gray)
   	(frequency isa schema interface transporter node-name frequency child1 enter-frequency child2 type child3 accept-frequency child4 nothing)
   		(enter-frequency isa find-button interface transporter node-name enter-frequency  xcor1 500 xcor2 530 ycor1 145 ycor2 175 kind oval value oval color light-gray)
   		(type-frequency isa type interface transporter node-name type-frequency  xcor1 460 xcor2 490 ycor1 185 ycor2 215 kind text value nothing color black key 5)
                (accept-frequency isa find-button interface transporter node-name accept-frequency  xcor1 435 xcor2 465 ycor1 215 ycor2 245 kind visual-object value box color light-gray)
        (power isa schema interface transporter node-name power child1 transporter-power child2 synchronous-mode child3 transporter-shoot child4 nothing)
        	(transporter-power isa find-button interface transporter node-name transporter-power  xcor1 185 xcor2 215 ycor1 215 ycor2 245 kind visual-object value box color light-gray)
                (synchronous-mode isa find-button interface transporter node-name synchronous-mode  xcor1 245 xcor2 275 ycor1 145 ycor2 175 kind oval value oval color light-gray)
                (transporter-shoot isa find-button interface transporter node-name transporter-shoot  xcor1 120 xcor2 450 ycor1 350 ycor2 700 kind visual-object value unknown color black)
        (main-control-transporter isa schema interface transporter node-name main-control-transporter child1 synchronous-mode2 child2 transporter-check-status child3 click-main-control-transporter child4 nothing)
                (synchronous-mode2 isa find-button interface transporter node-name synchronous-mode2  xcor1 245 xcor2 275 ycor1 145 ycor2 175 kind oval value oval color light-gray)
   		(transporter-check-status isa find-button interface transporter node-name transporter-check-status  xcor1 530 xcor2 800 ycor1 460 ycor2 500 kind text value nothing color black)
        	(click-main-control-transporter isa find-button interface transporter node-name click-main-control-transporter  xcor1 545 xcor2 575 ycor1 580 ycor2 610 kind oval value oval color light-gray)
    


  ;;; (frequency, scanner, power, shoot)
   (jammer-goal isa star-trek-goal state-global enter-frequency state-local retrieve state-micro nothing wm-dummy1 wm-dummy-chunk1 wm-dummy2 wm-dummy-chunk2 wm-dummy3 wm-dummy-chunk3)
   (do-jammer isa schema interface transporter node-name do-jammer child1 frequency child2 scan child3 power child4 main-control-transporter)
   (jammer-imaginal isa problem-state interface transporter top do-jammer middle frequency bottom enter-frequency)



   (wm-dummy-chunk1 isa wm-dummy value "a")
   (wm-dummy-chunk2 isa wm-dummy value "b")
   (wm-dummy-chunk3 isa wm-dummy value "c")
   (nothing isa wm-dummy value "nothing")
   
   )

  (sdp-fct '((power-connected2 :base-level -1.2) (tracking2 :base-level -1.1) (scanner-on :base-level -0.4) (scanner-off :base-level -0.4) (synchronous-mode2 :base-level -0.4)))

  (set-similarities
    (phaser-goal do-phaser -0.95) (phaser-goal charge-phaser -0.95) (phaser-goal set-focus -0.95) (phaser-goal fire-phaser -0.95) (phaser-goal main-control-phaser -0.95)
    (do-phaser charge-phaser -0.95) (do-phaser set-focus -0.95) (do-phaser fire-phaser -0.95) (do-phaser main-control-phaser -0.95)
   	(charge-phaser power-connected -0.95) (charge-phaser charge -0.95) (charge-phaser stop-charging -0.95) (charge-phaser power-connected2 -0.95)
      (set-focus settings -0.95) (set-focus slider -0.95) (set-focus focus-set -0.95)
      (fire-phaser firing -0.95) (fire-phaser tracking -0.95) (fire-phaser phaser-shoot -0.95) (fire-phaser phaser-check-status -0.95)
      (main-control-phaser click-main-control-phaser -0.95)
      (power-connected charge -0.95) (power-connected stop-charging -0.95) (power-connected power-connected2 -0.95)
      (charge stop-charging -0.95) (charge power-connected2 -0.95)
      (stop-charging power-connected2 -0.95)
      (settings slider -0.95) (settings focus-set -0.95) (slider focus-set -0.95)
      (firing tracking -0.95) (firing phaser-shoot -0.95) (firing phaser-check-status -0.95)
      (tracking phaser-shoot -0.95) (tracking phaser-check-status -0.95)
      (phaser-shoot phaser-check-status -0.95)
      (tracking2 click-main-control-phaser -0.7)

      (do-phaser power-connected -1) (do-phaser charge -1) (do-phaser stop-charging -1) (do-phaser power-connected2 -1) (do-phaser settings -1) (do-phaser slider -1) (do-phaser focus-set -1) (do-phaser firing -1) (do-phaser tracking -1) (do-phaser phaser-shoot -1) (do-phaser phaser-check-status -1) (do-phaser tracking2 -1) (do-phaser click-main-control-phaser -1)
      (charge-phaser set-focus -1) (charge-phaser fire-phaser -1) (charge-phaser main-control-phaser -1) (set-focus fire-phaser -1) (set-focus main-control-phaser -1) (fire-phaser main-control-phaser -1)
      (charge-phaser settings -1) (charge-phaser slider -1) (charge-phaser focus-set -1) (charge-phaser firing -1) (charge-phaser tracking -1) (charge-phaser phaser-shoot -1) (charge-phaser phaser-check-status -1) (charge-phaser tracking2 -1) (charge-phaser click-main-control-phaser -1)
      	(power-connected settings -1) (power-connected slider -1) (power-connected focus-set -1) (power-connected firing -1) (power-connected tracking -1) (power-connected phaser-shoot -1) (power-connected phaser-check-status -1) (power-connected tracking2 -1) (power-connected click-main-control-phaser -1)
      	(charge settings -1) (charge slider -1) (charge focus-set -1) (charge firing -1) (charge tracking -1) (charge phaser-shoot -1) (charge phaser-check-status -1) (charge tracking2 -1) (charge click-main-control-phaser -1)
      	(stop-charging settings -1) (stop-charging slider -1) (stop-charging focus-set -1) (stop-charging firing -1) (stop-charging tracking -1) (stop-charging phaser-shoot -1) (stop-charging phaser-check-status -1) (stop-charging tracking2 -1) (stop-charging click-main-control-phaser -1)
      	(power-connected2 settings -0.8) (power-connected2 slider -1) (power-connected2 focus-set -1) (power-connected2 firing -1) (power-connected2 tracking -1) (power-connected2 phaser-shoot -1) (power-connected2 phaser-check-status -1) (power-connected2 tracking2 -1) (power-connected2 click-main-control-phaser -1)
      (set-focus power-connected -1) (set-focus charge -1) (set-focus stop-charging -1) (set-focus power-connected2 -1) (set-focus firing -1) (set-focus tracking -1) (set-focus phaser-shoot -1) (set-focus phaser-check-status -1) (set-focus tracking2 -1) (set-focus click-main-control-phaser -1)
      	(settings firing -1) (settings tracking -1) (settings phaser-shoot -1) (settings phaser-check-status -1) (settings tracking2 -1) (settings click-main-control-phaser -1)
      	(slider firing -1) (slider tracking -1) (slider phaser-shoot -1) (slider phaser-check-status -1) (slider tracking2 -1) (slider click-main-control-phaser -1)
      	(focus-set firing -1) (focus-set tracking -1) (focus-set phaser-shoot -1) (focus-set phaser-check-status -1) (focus-set tracking2 -1) (focus-set click-main-control-phaser -1)
      (fire-phaser power-connected -1) (fire-phaser charge -1) (fire-phaser stop-charging -1) (fire-phaser power-connected2 -1) (fire-phaser settings -1) (fire-phaser slider -1) (fire-phaser focus-set -1) (fire-phaser click-main-control-phaser -1)
      	(firing click-main-control-phaser -1)
      	(tracking click-main-control-phaser -1)
      	(phaser-shoot click-main-control-phaser -1)
      	(phaser-check-status click-main-control-phaser -1)      
        (main-control-phaser power-connected -1) (main-control-phaser charge -1) (main-control-phaser stop-charging -1) (main-control-phaser power-connected2 -1) (main-control-phaser settings -1) (main-control-phaser slider -1) (main-control-phaser focus-set -1) (main-control-phaser firing -1) (main-control-phaser tracking -1) (main-control-phaser phaser-shoot -1) (main-control-phaser tracking2 -1) (main-control-phaser phaser-check-status -1)
      

   (transporter-goal do-transporter -0.95) (transporter-goal scan -0.95) (transporter-goal frequency -0.95) (transporter-goal power -0.95) (transporter-goal main-control-transporter -0.95)
   (jammer-goal do-jammer -0.95) (jammer-goal scan -0.95) (jammer-goal frequency -0.95) (jammer-goal power -0.95) (jammer-goal main-control-transporter -0.95)
   (do-transporter scan -0.95) (do-transporter frequency -0.95) (do-transporter power -0.95) (do-transporter main-control-transporter -0.95)
   (do-jammer scan -0.95) (do-jammer frequency -0.95) (do-jammer power -0.95) (do-jammer main-control-transporter -0.95)
   	(scan scanner-on -0.95) (scan active-scan -0.95) (scan lock-signal -0.95) (scan scanner-off -0.95) 
        (scanner-on active-scan -0.75) (scanner-on lock-signal -0.85) (scanner-on scanner-off -0.85) (active-scan lock-signal -0.9) (active-scan scanner-off -0.9) (lock-signal scanner-off -0.72)
      (frequency enter-frequency -0.95) (frequency type-frequency -0.95) (frequency accept-frequency -0.95) (enter-frequency type-frequency -0.95) (enter-frequency accept-frequency -0.95) (type-frequency accept-frequency -0.95)
      (power transporter-power -0.95) (power synchronous-mode -0.95) (power transporter-shoot -0.95)  (power transporter-check-status -0.95) 
      (transporter-power synchronous-mode -0.95) (transporter-power transporter-shoot -0.95)  (transporter-power transporter-check-status -0.95) (synchronous-mode transporter-shoot -0.95)   
      (main-control-transporter synchronous-mode2 -0.95) (main-control-transporter transporter-check-status -0.95) (main-control-transporter click-main-control-transporter -0.95)
      (synchronous-mode2 transporter-check-status -0.95) (synchronous-mode2 click-main-control-transporter -0.9) (transporter-check-status click-main-control-transporter -0.95)

      (do-transporter scanner-on -1) (do-transporter active-scan -1) (do-transporter lock-signal -1) (do-transporter scanner-off -1) (do-transporter enter-frequency -1) (do-transporter type-frequency -1) (do-transporter accept-frequency -1) (do-transporter transporter-power -1) (do-transporter synchronous-mode -1) (do-transporter transporter-shoot -1) (do-transporter synchronous-mode2 -1) (do-transporter transporter-check-status -1) (do-transporter click-main-control-transporter -1)
      (do-jammer scanner-on -1) (do-jammer active-scan -1) (do-jammer lock-signal -1) (do-jammer scanner-off -1) (do-jammer enter-frequency -1) (do-jammer type-frequency -1) (do-jammer accept-frequency -1) (do-jammer transporter-power -1) (do-jammer synchronous-mode -1) (do-jammer transporter-shoot -1) (do-jammer synchronous-mode2 -1) (do-jammer transporter-check-status -1) (do-jammer click-main-control-transporter -1)
      (scan enter-frequency -1) (scan type-frequency -1) (scan accept-frequency -1) (scan transporter-power -1) (scan synchronous-mode -1) (scan transporter-shoot -1) (scan synchronous-mode2 -1) (scan transporter-check-status -1) (scan click-main-control-transporter -1)
      (scanner-on enter-frequency -0.9) (scanner-on type-frequency -1) (scanner-on accept-frequency -1) (scanner-on transporter-power -1) (scanner-on synchronous-mode -1) (scanner-on transporter-shoot -1) (scanner-on synchronous-mode2 -1) (scanner-on transporter-check-status -1) (scanner-on click-main-control-transporter -1)
      (active-scan enter-frequency -0.9) (active-scan type-frequency -1) (active-scan accept-frequency -1) (active-scan transporter-power -1) (active-scan synchronous-mode -1) (active-scan transporter-shoot -1) (active-scan synchronous-mode2 -1) (active-scan transporter-check-status -1) (active-scan click-main-control-transporter -1)
      (lock-signal enter-frequency -0.9) (lock-signal type-frequency -1) (lock-signal accept-frequency -1) (lock-signal transporter-power -1) (lock-signal synchronous-mode -1) (lock-signal transporter-shoot -1) (lock-signal synchronous-mode2 -1) (lock-signal transporter-check-status -1) (lock-signal click-main-control-transporter -1)
      (scanner-off enter-frequency -0.7) (scanner-off type-frequency -1) (scanner-off accept-frequency -1) (scanner-off transporter-power -1) (scanner-off synchronous-mode -1) (scanner-off transporter-shoot -1) (scanner-off synchronous-mode2 -1) (scanner-off transporter-check-status -1) (scanner-off click-main-control-transporter -1)
      (frequency transporter-power -1) (frequency synchronous-mode -1) (frequency transporter-shoot -1) (frequency synchronous-mode2 -1) (frequency transporter-check-status -1) (frequency click-main-control-transporter -1)
      (enter-frequency transporter-power -1) (enter-frequency synchronous-mode -1) (enter-frequency transporter-shoot -1) (enter-frequency synchronous-mode2 -1) (enter-frequency transporter-check-status -1) (enter-frequency click-main-control-transporter -1)
      (type-frequency transporter-power -1) (type-frequency synchronous-mode -1) (type-frequency transporter-shoot -1) (type-frequency synchronous-mode2 -1) (type-frequency transporter-check-status -1) (type-frequency click-main-control-transporter -1)
      (accept-frequency transporter-power -1) (accept-frequency synchronous-mode -1) (accept-frequency transporter-shoot -1) (accept-frequency synchronous-mode2 -1) (accept-frequency transporter-check-status -1) (accept-frequency click-main-control-transporter -1)
      (transporter-power click-main-control-transporter -1)
      (synchronous-mode synchronous-mode2 -1) (synchronous-mode transporter-check-status -1) (synchronous-mode click-main-control-transporter -1)
      (transporter-shoot synchronous-mode2 -1) (transporter-shoot transporter-check-status -1) (transporter-shoot click-main-control-transporter -1)
      (transporter-shoot click-main-control-transporter -1)
      (transporter-check-status click-main-control-transporter -1)
      )


  (start-hand-at-mouse)
  
  
  
  
  
#|
(defun generic-rfm-productions3 ())
|#


(p retrieve
   ?aural-location>
	buffer empty
   =goal>
   	isa star-trek-goal
	state-global =nn
        state-local retrieve
        - state-micro =nn 
        state-micro =sm
   ?manual>
	state free
   ?retrieval>
   	state free
==>
   +retrieval>
   	isa find-button 
   	node-name =nn
        - node-name =sm
   =goal>
   	state-local find
)

(p post-error-retrieve-the-same
   =aural-location>
	isa audio-event
	kind wrong-click-buzzer
   =goal>
   	isa star-trek-goal
	state-global =nn
        state-local retrieve
        - state-micro =nn 
        state-micro =sm
   ?manual>
	state free
   ?retrieval>
   	state free
==>
   +retrieval>
   	isa find-button 
   	node-name =nn
        - node-name =sm
   =goal>
   	state-local find
 )

(p post-error-retrieve-something-else
   =aural-location>
	isa audio-event
	kind wrong-click-buzzer
   =goal>
   	isa star-trek-goal
	state-global =nn
        state-local retrieve
        - state-micro =nn 
        state-micro =sm
   =imaginal>
	isa problem-state
        interface =i
   ?retrieval>
	state free
==>
   =goal>
	state-local find
   +retrieval>
   	isa find-button 
        interface =i
   	- node-name =nn
)


(p find
   =goal>
   	isa star-trek-goal
        state-local find
   =retrieval>
   	isa find-button
        node-name =nn
        xcor1       =x1
        xcor2       =x2
        ycor1       =y1
        ycor2       =y2
        kind =k
        color =c
==>
   +visual-location>
      ISA         visual-location
      screen-x    (within =x1 =x2)
      screen-y    (within =y1 =y2)
      kind =k
      color =c
   =goal>
   	state-local move
)

(p move-mouse-cursor
   =goal>
	isa star-trek-goal
        state-local move
   =visual-location>
	isa visual-location
        - kind text
        - value blip
   =retrieval>
	isa find-button
   ?manual>
	preparation free
==>
   =goal>
	state-local click
   +manual>
	isa move-cursor
        loc =visual-location
;; !eval! (buffer-chunk visual-location)
)

(p find-visual-location-failure-retrieve-the-same
   =goal>
	isa star-trek-goal
        state-global =nn
        state-local move
        state-micro =sm
   ?visual-location>
	state error
==>
   +retrieval>
   	isa find-button 
   	node-name =nn
        - node-name =sm
   =goal>
   	state-local find
 )

(p find-visual-location-failure-retrieve-something-else
   =goal>
	isa star-trek-goal
        state-global =nn
        state-local move
   =imaginal>
	isa problem-state
        interface =i
   ?visual-location>
	state error
==>
   =goal>
	state-local find
   +retrieval>
   	isa find-button 
        interface =i
   	- node-name =nn
)	

(p move-visual-attention-text
   =goal>
	isa star-trek-goal
        state-local move
   =visual-location>
	isa visual-location
        kind text
   =retrieval>
	isa find-button
   ?visual>
	state free
==>
   =goal>
	state-local read
   +visual>
	isa move-attention
	screen-pos =visual-location
;; !eval! (buffer-chunk visual-location)
)

(p move-visual-attention-blip
   =goal>
	isa star-trek-goal
        state-local move
   =visual-location>
	isa visual-location
        kind visual-object
        value blip
   =retrieval>
	isa find-button
   ?visual>
	state free
==>
   =goal>
	state-local blip
   +visual>
	isa move-attention
	screen-pos =visual-location
;; !eval! (buffer-chunk visual-location)
)

(p click
   =goal>
	isa star-trek-goal
        state-local click
   ?manual>
	preparation free
==>
   +manual>
	isa click-mouse
   =goal>
	state-local verify
   )

(p verify-a-buzzer
   =aural-location>
	isa audio-event
	kind wrong-click-buzzer
   =goal>
	isa star-trek-goal
        state-local verify
        state-global =nn
   =imaginal>
	isa problem-state
        interface =i
   ?manual>
	state free
   ?retrieval>
	state free
==>
   =goal>
	state-local retrieve
   =aural-location>
   )

(p retrieval-error-try-again
   =goal>
	isa star-trek-goal
    =imaginal>
	isa problem-state
        bottom =nn
   ?retrieval>
	state error
==>
   +retrieval>
	isa find-button
        node-name =nn
   =goal>
	state-local find
        )







  ;;;;;;;;;;;;;;;;;;;;;;;;;;  
  ;;; phaser-no-interruption/semantic control
  ;;;;;;;;;;;;;;;;;;;;;;;;;;
  
  #|
(defun phaser3)
|#

(p power-connected1-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name power-connected
        color light-gray
==>
   =goal>
	state-global charge
        state-local retrieve
   =imaginal>
	bottom charge
        middle charge-phaser
   )

(p charge-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name charge
==>
   =goal>
	state-global stop-charging
        state-local retrieve
   =imaginal>
	bottom stop-charging
        middle charge-phaser
   )

(p stop-charging-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name stop-charging
==>
   =goal>
	state-global power-connected2
        state-local retrieve
   =imaginal>
	bottom power-connected2
        middle charge-phaser
   )

(p power-connected2-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name power-connected2
        color blue
==>
   =goal>
	state-global settings
        state-local retrieve
   =imaginal>
	bottom settings
        middle set-focus
   )

(p settings-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name settings
==>
   =goal>
	state-global slider
        state-local retrieve
   =imaginal>
	bottom slider
        middle set-focus
   )

(p slider-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name slider
==>
   =goal>
	state-global focus-set
        state-local retrieve
   =imaginal>
	bottom focus-set
        middle set-focus
   )

(p focus-set-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name focus-set
==>
   =goal>
	state-global firing
        state-local retrieve
   =imaginal>
	bottom firing
        middle fire-phaser
   )

(p firing-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name firing
==>
   =goal>
	state-global tracking
        state-local retrieve
   =imaginal>
	bottom tracking
        middle fire-phaser
   )

(p tracking-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name tracking
==>
   =goal>
	state-global phaser-shoot
        state-local retrieve
   =imaginal>
	bottom phaser-shoot
        middle fire-phaser
   )

(p phaser-shoot-act
   =goal>
   	isa star-trek-goal
        state-local blip
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name phaser-shoot
   ?manual>
	preparation free
==>
   +manual>
	isa punch
        hand left
        finger thumb
   =goal>
        state-local verify
   )

(p phaser-shoot-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name phaser-shoot
==>
   =goal>
	state-global phaser-check-status
        state-local retrieve
   =imaginal>
	bottom phaser-check-status
        middle fire-phaser
   )

(p romulans-not-destroyed
   =goal>
	isa star-trek-goal
        state-local read
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name phaser-check-status
   =visual-location>
	isa visual-location
        kind text
   =visual>
	isa text
   	- value "destroyed"
==>
   =goal>
	state-global power-connected
   	state-local retrieve
   =imaginal>
	middle charge-phaser
        bottom power-connected)

(p romulans-destroyed
   =goal>
	isa star-trek-goal
        state-local read
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name phaser-check-status
   =visual-location>
	isa visual-location
        kind text
   =visual>
	isa text
   	value "destroyed"
==>
   =goal>
	state-global tracking2
        state-local retrieve
   =imaginal>
	middle main-control-phaser
        bottom tracking2)

(p tracking2-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name tracking2
==>
   =goal>
	state-global click-main-control-phaser
	state-local retrieve
   =imaginal>
	middle main-control-phaser
	bottom click-main-control-phaser
   )

(p click-main-control-phaser-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name click-main-control-phaser
==>
   =goal>
	state-global finished-task
        state-local nil
   =imaginal>
	bottom finished-task
   )



#|
(defun transporter3)
|#

(p scanner-on-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name scanner-on
==>
   =goal>
	state-global active-scan
        state-local retrieve
   =imaginal>
	bottom active-scan)

(p active-scan-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name active-scan
==>
   =goal>
	state-global lock-signal
        state-local retrieve
   =imaginal>
	bottom lock-signal)

(p lock-signal-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name lock-signal
==>
   =goal>
	state-global scanner-off
        state-local retrieve
   =imaginal>
	bottom scanner-off)

(p transporter-scanner-off-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
        top do-transporter
   =retrieval>
	isa find-button
        node-name scanner-off
==>
   =goal>
	state-global enter-frequency
        state-local retrieve
   =imaginal>
	bottom enter-frequency
        middle frequency)

(p enter-frequency-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name enter-frequency
==>
   =goal>
	state-global type-frequency
        state-local retrieve
   =imaginal>
	bottom type-frequency)

(p type-frequency-act
   =goal>
   	isa star-trek-goal
        state-local read
   =imaginal>
	isa problem-state
   =visual-location>
	isa visual-location
        kind text
   =retrieval>
	isa type
        node-name type-frequency
        key =k
   ?manual>
	preparation free
==>
   +manual>
	isa press-key
	key =k
   =goal>
        state-local type-again)

(p type-frequency-click2
   =goal>
	isa star-trek-goal
        state-local type-again
   =imaginal>
	isa problem-state
   =retrieval>
	isa type
        node-name type-frequency
        key =k
   ?manual>
	preparation free
==>
   +manual>
	isa press-key
	key =k
   =goal>
        state-local verify
    )

(p type-frequency-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name type-frequency
==>
   =goal>
	state-global accept-frequency
        state-local retrieve
   =imaginal>
	bottom accept-frequency)

(p accept-frequency-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
        top do-transporter
   =retrieval>
	isa find-button
        node-name accept-frequency
==>
   =goal>
	state-global transporter-power
        state-local retrieve
   =imaginal>
	middle power
        bottom transporter-power)

(p transporter-power-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name transporter-power
==>
   =goal>
	state-global synchronous-mode
        state-local retrieve
   =imaginal>
	bottom synchronous-mode)

(p synchronous-mode1-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name synchronous-mode
==>
   =goal>
	state-global transporter-shoot
        state-local retrieve
   =imaginal>
	bottom transporter-shoot)

(p transporter-shoot-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name transporter-shoot
==>
   =goal>
	state-global synchronous-mode2
        state-local retrieve
   =imaginal>
	middle main-control-transporter
        bottom synchronous-mode2)

(p synchronous-mode2-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name synchronous-mode2
==>
   =goal>
	state-global transporter-check-status
        state-local retrieve
   =imaginal>
	bottom transporter-check-status)

(p transporter-beam-failed
   =goal>
	isa star-trek-goal
        state-local read
   =imaginal>
	isa problem-state
        top do-transporter
   =retrieval>
	isa find-button
        node-name transporter-check-status
   =visual-location>
	isa visual-location
        kind text
   =visual>
	isa text
   	- value "successful"
==>
   =goal>
	state-global scanner-on
   	state-local retrieve
   =imaginal>
	middle scan
        bottom scanner-on)

(p beam-successful
   =goal>
	isa star-trek-goal
 	state-global transporter-check-status
        state-local read
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name transporter-check-status
   =visual-location>
	isa visual-location
        kind text
   =visual>
	isa text
   	value "successful"
==>
   =goal>
	state-global click-main-control-transporter
        state-local retrieve
   =imaginal>
	middle main-control-transporter
        bottom click-main-control-transporter)

(p click-main-control-transporter-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
   =retrieval>
	isa find-button
        node-name click-main-control-transporter
==>
   =goal>
	state-global finished-task
        state-local nil
   =imaginal>
	bottom finished-task)






;;;;;;;;;;;;;;;;;;;;;;;;;;  
;;; new-jammer-static-subgoal-order
;;; (frequency, scanner, power, shoot)
;;;;;;;;;;;;;;;;;;;;;;;;;;

#|
(defun jammer3)
|#

(p jammer-accept-frequency-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
        top do-jammer
   =retrieval>
	isa find-button
        node-name accept-frequency
==>
   =goal>
	state-global scanner-on
        state-local retrieve
   =imaginal>
	middle scan
        bottom scanner-on)

(p jammer-scanner-off-verify-no-buzzer
   ?aural-location>
	buffer empty
   ?manual>
	state free
   =goal>
	isa star-trek-goal
        state-local verify
   =imaginal>
	isa problem-state
        top do-jammer
   =retrieval>
	isa find-button
        node-name scanner-off
==>
   =goal>
	state-global transporter-power
        state-local retrieve
   =imaginal>
	bottom transporter-power
        middle power)

(p jammer-beam-failed
   =goal>
	isa star-trek-goal
        state-local read
   =imaginal>
	isa problem-state
        top do-jammer
   =retrieval>
	isa find-button
        node-name transporter-check-status
   =visual-location>
	isa visual-location
        kind text
   =visual>
	isa text
   	- value "successful"
==>
   =goal>
	state-global enter-frequency
   	state-local retrieve
   =imaginal>
	middle frequency
        bottom enter-frequency)
















   
#|
(defun spp3)
|#
  
(spp 
 (post-error-retrieve-something-else :u -10)
 )
  
  
  (setf *actr-enabled-p* t)
  
  ;; define-model closing parenthesis
  )